@@ -27,14 +27,19 @@ var searchData=
   ['acc_5ftva',['Acc_Tva',['../classAcc__Tva.html',1,'']]],
   ['account_5fresult_2ephp',['account_result.php',['../account__result_8php.html',1,'']]],
   ['account_5fsearch_2ephp',['account_search.php',['../account__search_8php.html',1,'']]],
+  ['account_5fupdate',['account_update',['../accounting__item_8js.html#a334c0db0509d039e48e1557c6ac9bba4',1,'accounting_item.js']]],
   ['accounting_5fitem_2ejs',['accounting_item.js',['../accounting__item_8js.html',1,'']]],
   ['action',['ACTION',['../constant_8php.html#ae3a6b7e1199f276d75597e986e42c1a3',1,'constant.php']]],
   ['action_2ecommon_2einc_2ephp',['action.common.inc.php',['../action_8common_8inc_8php.html',1,'']]],
   ['action_2einc_2ephp',['action.inc.php',['../action_8inc_8php.html',1,'']]],
+  ['action_5fadd_5fconcerned_5fcard',['action_add_concerned_card',['../card_8js.html#a7ce6c3ddafad8aa4d0ac2b4a69313809',1,'card.js']]],
   ['action_5fbutton_2ephp',['action_button.php',['../action__button_8php.html',1,'']]],
+  ['action_5fhide_5fcheckbox',['action_hide_checkbox',['../scripts_8js.html#aa2b25c7e2ac14ce6c1d58d05327d65f6',1,'scripts.js']]],
   ['action_5fother_5faction_2ephp',['action_other_action.php',['../action__other__action_8php.html',1,'']]],
   ['action_5fprint',['action_print',['../classFollow__Up.html#ad3a09b42ef3d4a41527c380a4039b525',1,'Follow_Up']]],
   ['action_5fremove',['action_remove',['../classFollow__Up.html#a5523bbd2973b036add1277187b432759',1,'Follow_Up']]],
+  ['action_5fremove_5fconcerned',['action_remove_concerned',['../card_8js.html#a40698f63cb24dd6935a24c85969c5b46',1,'card.js']]],
+  ['action_5fsave_5fconcerned',['action_save_concerned',['../card_8js.html#aaebcc92a2adf74121f0da668c48b2dc9',1,'card.js']]],
   ['action_5fsearch_2ephp',['action_search.php',['../action__search_8php.html',1,'']]],
   ['action_5fsearch_5fresult_2ephp',['action_search_result.php',['../action__search__result_8php.html',1,'']]],
   ['action_5fset_5fstate',['action_set_state',['../classFollow__Up.html#a669ba4dbf5b18cd789b2f93ef91865fb',1,'Follow_Up']]],
@@ -53,6 +58,7 @@ var searchData=
   ['add_5fplugin',['add_plugin',['../scripts_8js.html#a6c4fc247991b9e4071f506903665e89a',1,'scripts.js']]],
   ['add_5frecurse_5ffolder',['add_recurse_folder',['../classZip__Extended.html#aed86de7271328d7727145ab727ced987',1,'Zip_Extended']]],
   ['add_5frow',['add_row',['../anc__script_8js.html#a36caae38586ac7398222d7e4acd0afb8',1,'anc_script.js']]],
+  ['add_5frow_5fkey',['add_row_key',['../anc__script_8js.html#a232bac6c18388c97a20f54048677cf09',1,'anc_script.js']]],
   ['add_5ftodo',['add_todo',['../todo__list_8js.html#ab13bd2a2981c1744152f7f26d997e9d7',1,'todo_list.js']]],
   ['addclass',['addClass',['../calendar_8js.html#ae0308570901bb71add31de7bf52a2233',1,'calendar.js']]],
   ['addevent',['addEvent',['../calendar_8js.html#aeda70ce28bae68d7e12049d7faa4d64e',1,'calendar.js']]],
@@ -62,7 +68,13 @@ var searchData=
   ['admin_5frepo_2ephp',['admin_repo.php',['../admin__repo_8php.html',1,'']]],
   ['ag_5fid',['ag_id',['../ajax__tag__add__action_8php.html#a6fb29855eac76fb03779e4025afc9858',1,'ag_id():&#160;ajax_tag_add_action.php'],['../ajax__tag__remove__action_8php.html#a6fb29855eac76fb03779e4025afc9858',1,'ag_id():&#160;ajax_tag_remove_action.php'],['../ajax__view__action_8php.html#a574afd3c823c918a374f0f29e984eafa',1,'ag_id():&#160;ajax_view_action.php']]],
   ['ajax_2ephp',['ajax.php',['../ajax_8php.html',1,'']]],
+  ['ajax_5faccount_5fupdate_2ephp',['ajax_account_update.php',['../ajax__account__update_8php.html',1,'']]],
+  ['ajax_5faction_5fremove_5fconcerned_2ephp',['ajax_action_remove_concerned.php',['../ajax__action__remove__concerned_8php.html',1,'']]],
+  ['ajax_5faction_5fsave_5fconcerned_2ephp',['ajax_action_save_concerned.php',['../ajax__action__save__concerned_8php.html',1,'']]],
+  ['ajax_5fadd_5fconcerned_5fcard_2ephp',['ajax_add_concerned_card.php',['../ajax__add__concerned__card_8php.html',1,'']]],
   ['ajax_5fadd_5fmenu_2ephp',['ajax_add_menu.php',['../ajax__add__menu_8php.html',1,'']]],
+  ['ajax_5fanc_5fkey_5fchoice_2ephp',['ajax_anc_key_choice.php',['../ajax__anc__key__choice_8php.html',1,'']]],
+  ['ajax_5fanc_5fkey_5fcompute_2ephp',['ajax_anc_key_compute.php',['../ajax__anc__key__compute_8php.html',1,'']]],
   ['ajax_5fanc_5fsearch_2ephp',['ajax_anc_search.php',['../ajax__anc__search_8php.html',1,'']]],
   ['ajax_5fauto_5fanc_5fcard_2ephp',['ajax_auto_anc_card.php',['../ajax__auto__anc__card_8php.html',1,'']]],
   ['ajax_5fbank_5fsaldo_2ephp',['ajax_bank_saldo.php',['../ajax__bank__saldo_8php.html',1,'']]],
@@ -120,7 +132,7 @@ var searchData=
   ['all',['ALL',['../constant_8php.html#aaff03f45544854747fa5e7821e84252e',1,'constant.php']]],
   ['all_5ffiche_5fdef_5fref',['ALL_FICHE_DEF_REF',['../constant_8php.html#a8eac9204dba23dc98198e1cd0d6a41be',1,'constant.php']]],
   ['allocatecolors',['allocateColors',['../classSecurimage.html#a31473e35d04239ae68d01ae37214fd7b',1,'Securimage']]],
-  ['allowed',['ALLOWED',['../admin__repo_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;admin_repo.php'],['../ajax_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax.php'],['../ajax__card_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_card.php'],['../ajax__history_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_history.php'],['../ajax__ledger_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_ledger.php'],['../ajax__misc_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_misc.php'],['../ajax__poste_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_poste.php'],['../ajax__todo__list_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_todo_list.php'],['../do_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;do.php'],['../export_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;export.php']]],
+  ['allowed',['ALLOWED',['../admin__repo_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;admin_repo.php'],['../ajax__todo__list_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;ajax_todo_list.php'],['../do_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;do.php'],['../export_8php.html#af61aa6ee68de80cd94042b2432fbf602',1,'ALLOWED():&#160;export.php']]],
   ['alter_5fseq',['alter_seq',['../classDatabase.html#a703563f2c8298f29fc991e4e1d42088f',1,'Database']]],
   ['amount_5fid',['amount_id',['../operation__ods__new_8inc_8php.html#af81426cd3a0330000e15e003b9e24dff',1,'operation_ods_new.inc.php']]],
   ['anc_5facc_5fbalance_2einc_2ephp',['anc_acc_balance.inc.php',['../anc__acc__balance_8inc_8php.html',1,'']]],
@@ -141,6 +153,18 @@ var searchData=
   ['anc_5fgroup_5fbalance_2einc_2ephp',['anc_group_balance.inc.php',['../anc__group__balance_8inc_8php.html',1,'']]],
   ['anc_5fgroup_5foperation',['Anc_Group_Operation',['../classAnc__Group__Operation.html',1,'Anc_Group_Operation'],['../classAnc__Group__Operation.html#ae28c800394bb534d0e24b02221de67b2',1,'Anc_Group_Operation\Anc_Group_Operation()']]],
   ['anc_5fhistory_2einc_2ephp',['anc_history.inc.php',['../anc__history_8inc_8php.html',1,'']]],
+  ['anc_5fkey',['Anc_Key',['../classAnc__Key.html',1,'']]],
+  ['anc_5fkey_2einc_2ephp',['anc_key.inc.php',['../anc__key_8inc_8php.html',1,'']]],
+  ['anc_5fkey_5factivity_5fsql',['Anc_Key_Activity_SQL',['../classAnc__Key__Activity__SQL.html',1,'']]],
+  ['anc_5fkey_5fchoice',['anc_key_choice',['../anc__script_8js.html#a52d84bacb02ab89ebd2298869616aea7',1,'anc_script.js']]],
+  ['anc_5fkey_5fcompute',['anc_key_compute',['../anc__script_8js.html#a98e23cfa9be201ac8a33831434d24635',1,'anc_script.js']]],
+  ['anc_5fkey_5fcompute_5ftable',['anc_key_compute_table',['../anc__script_8js.html#afa34a11c2abcbdc5aaab56e23009df8f',1,'anc_script.js']]],
+  ['anc_5fkey_5fdetail_5fsql',['Anc_Key_Detail_SQL',['../classAnc__Key__Detail__SQL.html',1,'']]],
+  ['anc_5fkey_5fdisplay_5fchoice_2ephp',['anc_key_display_choice.php',['../anc__key__display__choice_8php.html',1,'']]],
+  ['anc_5fkey_5fdisplay_5flist_2ephp',['anc_key_display_list.php',['../anc__key__display__list_8php.html',1,'']]],
+  ['anc_5fkey_5finput_2ephp',['anc_key_input.php',['../anc__key__input_8php.html',1,'']]],
+  ['anc_5fkey_5fledger_5fsql',['Anc_Key_Ledger_SQL',['../classAnc__Key__Ledger__SQL.html',1,'']]],
+  ['anc_5fkey_5fsql',['Anc_Key_SQL',['../classAnc__Key__SQL.html',1,'']]],
   ['anc_5flisting',['Anc_Listing',['../classAnc__Listing.html',1,'']]],
   ['anc_5fod_2einc_2ephp',['anc_od.inc.php',['../anc__od_8inc_8php.html',1,'']]],
   ['anc_5foperation',['Anc_Operation',['../classAnc__Operation.html',1,'Anc_Operation'],['../classAnc__Operation.html#ad4e0072bcd45a67b5c9dd2a61452a2d8',1,'Anc_Operation\Anc_Operation()']]],
@@ -151,9 +175,10 @@ var searchData=
   ['anc_5fremove_5foperation',['anc_remove_operation',['../anc__script_8js.html#a8bb87100b0ea0bf694d6944828891a42',1,'anc_script.js']]],
   ['anc_5fscript_2ejs',['anc_script.js',['../anc__script_8js.html',1,'']]],
   ['anc_5ftable',['Anc_Table',['../classAnc__Table.html',1,'']]],
-  ['anchor',['anchor',['../classDocument.html#a8644b3eb98db339ac213558781da7c07',1,'Document\anchor()'],['../classHtmlInput.html#ae85dda301049765c74caa911e14a5ba6',1,'HtmlInput\anchor()']]],
+  ['anchor',['anchor',['../classDocument.html#a8644b3eb98db339ac213558781da7c07',1,'Document\anchor()'],['../classHtmlInput.html#ab7a52c4e432f073fd7760e426162ea31',1,'HtmlInput\anchor()']]],
   ['anchor_5fclose',['anchor_close',['../classHtmlInput.html#afc8654bf16f03d25d55fd767c187ad2b',1,'HtmlInput']]],
   ['anchor_5fhide',['anchor_hide',['../classHtmlInput.html#acb2db375327ea94730bcfa43781416d1',1,'HtmlInput']]],
+  ['ann_c3_a9e',['année',['../infobulle_8js.html#a5ddac41e523b7610f9c8972da8410d27',1,'infobulle.js']]],
   ['anticipation',['Anticipation',['../classAnticipation.html',1,'']]],
   ['apply_5fpatch',['apply_patch',['../classDatabase.html#abedc355e1add04090585ab8e6301f25b',1,'Database']]],
   ['array_5fcat',['array_cat',['../classAcc__Ledger.html#a5fd88708bad274b593dea88e6d450d32',1,'Acc_Ledger']]],
