@@ -37,6 +37,7 @@ var searchData=
   ['centralized',['centralized',['../classPeriode.html#a56b912e22f71b16c4151fcac8007d600',1,'Periode']]],
   ['cfgfiche_2einc_2ephp',['cfgfiche.inc.php',['../cfgfiche_8inc_8php.html',1,'']]],
   ['cfgledger_2einc_2ephp',['cfgledger.inc.php',['../cfgledger_8inc_8php.html',1,'']]],
+  ['cfgplugin_2einc_2ephp',['cfgplugin.inc.php',['../cfgplugin_8inc_8php.html',1,'']]],
   ['cfgtags_2einc_2ephp',['cfgtags.inc.php',['../cfgtags_8inc_8php.html',1,'']]],
   ['change_5fmonth',['change_month',['../scripts_8js.html#a2ee868770eb2aaa0f5456b7cb9d64a2c',1,'scripts.js']]],
   ['check',['Check',['../classUser.html#a74a50425ee9908b9e00414a720873d95',1,'User\Check()'],['../classAcc__Account.html#a27f5c27efa29c3323d9cf1782babd4fd',1,'Acc_Account\check()'],['../classAnc__Print.html#ad33c662b08a47abb9d114c797817bd4c',1,'Anc_Print\check()'],['../classDossier.html#a9cd05f29afc103ab12a0b39b305bfbf5',1,'Dossier\check()'],['../classOwn.html#a4ffe1cda33d13203d71cf26ea074bd02',1,'Own\check()'],['../classTodo__List.html#a7c3c1a20ed1dc01871489b03ddbd2638',1,'Todo_List\check()'],['../classTool__Uos.html#af4c09940a124ef232eb6284776036480',1,'Tool_Uos\check()'],['../classSecurimage.html#a0e4b6929fa43ef1495fe6b42c7c25ae3',1,'Securimage\check()']]],
@@ -45,19 +46,23 @@ var searchData=
   ['check_5fdate',['check_date',['../scripts_8js.html#a0d01859e801d3fc9fbe57ffc7b7f112a',1,'scripts.js']]],
   ['check_5fdate_5fid',['check_date_id',['../scripts_8js.html#a48e456abf90e79a26f4e1acf9c5cb6bf',1,'scripts.js']]],
   ['check_5fdossier',['check_dossier',['../classUser.html#ae5fa6f05dc778cf095c98b2a2d3b1e49',1,'User']]],
+  ['check_5ffile',['check_file',['../classDocument__Export.html#afd474eba0821f226057e4406b7136f64',1,'Document_Export']]],
   ['check_5fformula',['check_formula',['../classImpress.html#ac70c01ef3c43d4729df24addf5a6916b',1,'Impress']]],
   ['check_5fhour',['check_hour',['../gestion_8js.html#ac3d0e754c90b84afcffd98880fdc070f',1,'gestion.js']]],
   ['check_5fjrn',['check_jrn',['../classUser.html#a4fe77bd15bfa9d51f8c31123690ea618',1,'User']]],
   ['check_5fmodule',['check_module',['../classUser.html#a772684b674892d9e5d1b826fbeb9f9c2',1,'User']]],
+  ['check_5fparameter',['check_parameter',['../user__common_8php.html#a39a7a57106d51e14afb9fcf7e0cc8975',1,'user_common.php']]],
   ['check_5fpayment',['check_payment',['../classAcc__Ledger.html#ac9440523be7d40f059aaa94b4e4b9326',1,'Acc_Ledger']]],
   ['check_5fperiode',['check_periode',['../classAcc__Ledger.html#ad886bafbcaf7dbb73bee298c5836c045',1,'Acc_Ledger']]],
   ['check_5fplugin_5fversion',['check_plugin_version',['../classExtension.html#a493fc3136378d428ed1f65d427d60029',1,'Extension']]],
   ['check_5fprint',['check_print',['../classUser.html#a38c889f36ccc86c120cbe5ba4b9f85a1',1,'User']]],
   ['check_5fstrict',['check_strict',['../classAcc__Ledger.html#ae37d2f8ec91fe2546d199e128849db65',1,'Acc_Ledger']]],
   ['check_5fversion',['check_version',['../classExtension.html#ae253b46483a4bd8680aa196f8ec7380d',1,'Extension']]],
+  ['check_5fxml',['check_xml',['../classExtension.html#a7645cf42c2850107b5a14402e0a26980',1,'Extension']]],
   ['checkcode',['checkCode',['../classSecurimage.html#ac171beeb6714ff77a878d174177ab7a0',1,'Securimage']]],
   ['checktotal',['checkTotal',['../compute_8js.html#a97b5d8943662b77791b7990e84917637',1,'compute.js']]],
   ['checktotaldirect',['checkTotalDirect',['../compute__direct_8js.html#a11f3f0d141534c20a1d1b72bf2896eb9',1,'compute_direct.js']]],
+  ['class',['class',['../detail-action_8php.html#a185c73c6507391d1eb38c776b68ce96d',1,'detail-action.php']]],
   ['class_5facc_5faccount_2ephp',['class_acc_account.php',['../class__acc__account_8php.html',1,'']]],
   ['class_5facc_5faccount_5fledger_2ephp',['class_acc_account_ledger.php',['../class__acc__account__ledger_8php.html',1,'']]],
   ['class_5facc_5fbalance_2ephp',['class_acc_balance.php',['../class__acc__balance_8php.html',1,'']]],
@@ -84,6 +89,8 @@ var searchData=
   ['class_5fanc_5fgrandlivre_2ephp',['class_anc_grandlivre.php',['../class__anc__grandlivre_8php.html',1,'']]],
   ['class_5fanc_5fgroup_2ephp',['class_anc_group.php',['../class__anc__group_8php.html',1,'']]],
   ['class_5fanc_5fgroup_5foperation_2ephp',['class_anc_group_operation.php',['../class__anc__group__operation_8php.html',1,'']]],
+  ['class_5fanc_5fkey_2ephp',['class_anc_key.php',['../class__anc__key_8php.html',1,'']]],
+  ['class_5fanc_5fkey_5fsql_2ephp',['class_anc_key_sql.php',['../class__anc__key__sql_8php.html',1,'']]],
   ['class_5fanc_5flisting_2ephp',['class_anc_listing.php',['../class__anc__listing_8php.html',1,'']]],
   ['class_5fanc_5foperation_2ephp',['class_anc_operation.php',['../class__anc__operation_8php.html',1,'']]],
   ['class_5fanc_5fplan_2ephp',['class_anc_plan.php',['../class__anc__plan_8php.html',1,'']]],
@@ -98,6 +105,7 @@ var searchData=
   ['class_5fdefault_5fmenu_2ephp',['class_default_menu.php',['../class__default__menu_8php.html',1,'']]],
   ['class_5fdefault_5fmenu_5fsql_2ephp',['class_default_menu_sql.php',['../class__default__menu__sql_8php.html',1,'']]],
   ['class_5fdocument_2ephp',['class_document.php',['../class__document_8php.html',1,'']]],
+  ['class_5fdocument_5fexport_2ephp',['class_document_export.php',['../class__document__export_8php.html',1,'']]],
   ['class_5fdocument_5fmodele_2ephp',['class_document_modele.php',['../class__document__modele_8php.html',1,'']]],
   ['class_5fdocument_5ftype_2ephp',['class_document_type.php',['../class__document__type_8php.html',1,'']]],
   ['class_5fdossier_2ephp',['class_dossier.php',['../class__dossier_8php.html',1,'']]],
@@ -144,10 +152,10 @@ var searchData=
   ['class_5fmanager_2ephp',['class_manager.php',['../class__manager_8php.html',1,'']]],
   ['class_5fmenu_5fref_2ephp',['class_menu_ref.php',['../class__menu__ref_8php.html',1,'']]],
   ['class_5fmenu_5fref_5fsql_2ephp',['class_menu_ref_sql.php',['../class__menu__ref__sql_8php.html',1,'']]],
+  ['class_5fnoalyss_5fsql_2ephp',['class_noalyss_sql.php',['../class__noalyss__sql_8php.html',1,'']]],
   ['class_5fown_2ephp',['class_own.php',['../class__own_8php.html',1,'']]],
   ['class_5fpdf_2ephp',['class_pdf.php',['../class__pdf_8php.html',1,'']]],
   ['class_5fperiode_2ephp',['class_periode.php',['../class__periode_8php.html',1,'']]],
-  ['class_5fphpcompta_5fsql_2ephp',['class_phpcompta_sql.php',['../class__phpcompta__sql_8php.html',1,'']]],
   ['class_5fpre_5fop_5fach_2ephp',['class_pre_op_ach.php',['../class__pre__op__ach_8php.html',1,'']]],
   ['class_5fpre_5fop_5fadvanced_2ephp',['class_pre_op_advanced.php',['../class__pre__op__advanced_8php.html',1,'']]],
   ['class_5fpre_5fop_5ffin_2ephp',['class_pre_op_fin.php',['../class__pre__op__fin_8php.html',1,'']]],
@@ -179,6 +187,7 @@ var searchData=
   ['class_5fzip_5fextended_2ephp',['class_zip_extended.php',['../class__zip__extended_8php.html',1,'']]],
   ['clean',['clean',['../classExtension.html#a48236d8b6d0c22703c4351e8b6952b81',1,'Extension\clean()'],['../calc_8js.html#a766dc2f59099f202272df8dfe4c3f8d5',1,'Clean():&#160;calc.js']]],
   ['clean_5ffid',['clean_Fid',['../ajax__fiche_8js.html#a1b4bbd038085e1377b27935b817fad8c',1,'clean_Fid(p_ctl):&#160;ajax_fiche.js'],['../card_8js.html#a1b4bbd038085e1377b27935b817fad8c',1,'clean_Fid(p_ctl):&#160;card.js']]],
+  ['clean_5ffolder',['clean_folder',['../classDocument__Export.html#aee6a5a5918b170e8225ff49a64979924',1,'Document_Export']]],
   ['clean_5fledger',['clean_ledger',['../acc__ledger_8js.html#a7e3644b137336a0199c7300fdd4f541e',1,'acc_ledger.js']]],
   ['clean_5ftva',['clean_tva',['../acc__ledger_8js.html#af655f0c087463cc5f209e8fa727490c2',1,'acc_ledger.js']]],
   ['cleanurl',['CleanUrl',['../user__common_8php.html#aa83ae78ac3200196202f2a09cfc81c58',1,'user_common.php']]],
@@ -187,12 +196,13 @@ var searchData=
   ['closed',['CLOSED',['../constant_8php.html#a1c148456651f25e8224a47d6af034c84',1,'constant.php']]],
   ['closure',['closure',['../nicEdit_8js.html#a59c341ec8fa48dd953c521ad1963d77c',1,'nicEdit.js']]],
   ['closurelistener',['closureListener',['../nicEdit_8js.html#a49a1c5fc58476c18b55e5acb1c4aea8c',1,'nicEdit.js']]],
-  ['cmp_5fname',['cmp_name',['../classFiche.html#a3c6bf2be7c5eef99ee997073b73739d5',1,'Fiche']]],
+  ['cmp_5fname',['cmp_name',['../classFiche.html#a50b50da0f7a4cb30681bf0026c224b9c',1,'Fiche']]],
   ['cmpdate',['cmpDate',['../ac__common_8php.html#af3b996f4767b690de50600a35108720f',1,'ac_common.php']]],
   ['cn',['cn',['../balance_8inc_8php.html#ab630ecb9532f81b133ae747372d32535',1,'balance.inc.php']]],
   ['cn_5futf8_2ejs',['cn_utf8.js',['../cn__utf8_8js.html',1,'']]],
   ['code_5fexcp_5fduplicate',['CODE_EXCP_DUPLICATE',['../class__tool__uos_8php.html#ad7fb0d5a90e9d8f0a1eafa1275ab7fd5',1,'class_tool_uos.php']]],
   ['code_5flength',['code_length',['../securimage__show__example2_8php.html#a19685947fbe90d58aad172a0472b6aab',1,'securimage_show_example2.php']]],
+  ['collect_5fobjects',['collect_objects',['../classNoalyss__SQL.html#ad8909f8f829278d33d0d4eec036d4d00',1,'Noalyss_SQL']]],
   ['commit',['commit',['../classDatabase.html#a2903b6c9ff18c27ce43fb79558bbcfee',1,'Database']]],
   ['company_2einc_2ephp',['company.inc.php',['../company_8inc_8php.html',1,'']]],
   ['compose',['compose',['../classSendmail.html#a2005d5cc1f89f0488db3bea20e92eddb',1,'Sendmail']]],
@@ -218,11 +228,12 @@ var searchData=
   ['compute_5fnd',['compute_nd',['../classAcc__Compute.html#a89fb07ba2d59c28120eadd621341316f',1,'Acc_Compute']]],
   ['compute_5fnd_5fvat',['compute_nd_vat',['../classAcc__Compute.html#a794bbdd0521152fef64745b92874483c',1,'Acc_Compute']]],
   ['compute_5fndded_5fvat',['compute_ndded_vat',['../classAcc__Compute.html#accd71e534cfc80a6e77efe9bc7ce7972',1,'Acc_Compute']]],
-  ['compute_5fno_5fdeductible',['compute_no_deductible',['../classAcc__Ledger__Purchase.html#a6243a9c14016f3f5586964a153095200',1,'Acc_Ledger_Purchase']]],
+  ['compute_5fno_5fdeductible',['compute_no_deductible',['../classAcc__Ledger__Purchase.html#a96ce097cc45670fbfdac9436c6948acf',1,'Acc_Ledger_Purchase']]],
   ['compute_5fperso',['compute_perso',['../classAcc__Compute.html#ad90f74683eb38ade7933cc66eead63b3',1,'Acc_Compute']]],
   ['compute_5ftotal_5ftable',['compute_total_table',['../anc__script_8js.html#ab5c05bae092bd358f626b393cb77c57b',1,'anc_script.js']]],
   ['compute_5fvariable',['compute_variable',['../ac__common_8php.html#a284cc59af73f7bab4cd6c2aaa3cc7ba6',1,'ac_common.php']]],
   ['compute_5fvat',['compute_vat',['../classAcc__Compute.html#a8af4d7edd2d7a23e592b1114dd70e24b',1,'Acc_Compute']]],
+  ['concatenate_5fpdf',['concatenate_pdf',['../classDocument__Export.html#a8d23cc84865e8b75d4311025e23a4ec1',1,'Document_Export']]],
   ['config_2einc',['config.inc',['../config_8inc.html',1,'']]],
   ['config_5ffile_2ephp',['config_file.php',['../config__file_8php.html',1,'']]],
   ['config_5ffile_5fcreate',['config_file_create',['../config__file_8php.html#a9e2d4a197ee6e9d98a22d28bd55fad10',1,'config_file.php']]],
@@ -236,10 +247,10 @@ var searchData=
   ['construct',['construct',['../nicEdit_8js.html#ac7ae32d97a8d31ea5765613c3e28190d',1,'nicEdit.js']]],
   ['contact',['contact',['../classcontact.html',1,'contact'],['../classcontact.html#a1fd1d15d165182dfa5f9ac9a275eef7e',1,'contact\contact()']]],
   ['contact_2einc_2ephp',['contact.inc.php',['../contact_8inc_8php.html',1,'']]],
-  ['content',['content',['../setup_8js.html#a269e8030357784cb1ef482d4d4d0073f',1,'content():&#160;setup.js'],['../infobulle_8js.html#a5af304dc2cc365fba2f906be228c5319',1,'content():&#160;infobulle.js']]],
+  ['content',['content',['../setup_8js.html#a269e8030357784cb1ef482d4d4d0073f',1,'content():&#160;setup.js'],['../infobulle_8js.html#afc2d3362d7541bab555b4c75ee5f8fac',1,'content():&#160;infobulle.js']]],
   ['convert_5ffrom_5ffollow',['convert_from_follow',['../classAcc__Ledger.html#ab22ffaa3d9baf41bf27e854da174d477',1,'Acc_Ledger']]],
   ['correct',['correct',['../classAcc__Compute.html#aa68223ffb6c58fbedef75f27bc81c0c0',1,'Acc_Compute']]],
-  ['count',['count',['../classAcc__Account.html#a7db428b3411135213bde4cef81272adf',1,'Acc_Account\count()'],['../classAcc__Ledger__Info.html#af86a36944e55ec2b1371a9c1da31c391',1,'Acc_Ledger_Info\count()'],['../classAnc__Plan.html#a930ab0bcc4a3ffd30b9df7ff1fa0a002',1,'Anc_Plan\count()'],['../classDatabase.html#ac96fe8fcfd596793c008dd81955cb4e9',1,'Database\count()'],['../classExercice.html#a5bdb0bf8b5a0e18e308c4287dff76b92',1,'Exercice\count()'],['../classPre__operation.html#a20663ebb2f39ba6957c4b39fa3104a45',1,'Pre_operation\count()'],['../classPre__operation__detail.html#adee6be28c4d0154cf192e881e6ff3351',1,'Pre_operation_detail\count()']]],
+  ['count',['count',['../classAcc__Account.html#a7db428b3411135213bde4cef81272adf',1,'Acc_Account\count()'],['../classAcc__Ledger__Info.html#af86a36944e55ec2b1371a9c1da31c391',1,'Acc_Ledger_Info\count()'],['../classAnc__Plan.html#a930ab0bcc4a3ffd30b9df7ff1fa0a002',1,'Anc_Plan\count()'],['../classDatabase.html#ac96fe8fcfd596793c008dd81955cb4e9',1,'Database\count()'],['../classExercice.html#a5bdb0bf8b5a0e18e308c4287dff76b92',1,'Exercice\count()'],['../classNoalyss__SQL.html#a4d1b4fe984743e0b19942f8cc76492c6',1,'Noalyss_SQL\count()'],['../classPre__operation.html#a20663ebb2f39ba6957c4b39fa3104a45',1,'Pre_operation\count()'],['../classPre__operation__detail.html#adee6be28c4d0154cf192e881e6ff3351',1,'Pre_operation_detail\count()']]],
   ['count_5fby_5fmodele',['count_by_modele',['../classFiche.html#aae77f784436d665401035af45ee33360',1,'Fiche']]],
   ['count_5fcategory',['count_category',['../classFiche__Def.html#a6d96741f8b35ada8819e776b37a1cc27',1,'Fiche_Def']]],
   ['count_5fsql',['count_sql',['../classDatabase.html#afd0a3cb7272674d94e8a8048582a68ee',1,'Database']]],
@@ -253,7 +264,7 @@ var searchData=
   ['createcode',['createCode',['../classSecurimage.html#a7d65189ba8813cd3f70fb416237ef9ce',1,'Securimage']]],
   ['createelement',['createElement',['../calendar_8js.html#a70992dfdaf7c536a96729443c905f278',1,'calendar.js']]],
   ['cred',['cred',['../export__balance__csv_8php.html#af9f0936e84e6469ee1683110b2cf05d9',1,'export_balance_csv.php']]],
-  ['css_5fsize',['css_size',['../param__pcmn_8inc_8php.html#a71ea389c571f69e0a9540e477329c3fd',1,'param_pcmn.inc.php']]],
+  ['css_5fsize',['css_size',['../param__pcmn_8inc_8php.html#a71ea389c571f69e0a9540e477329c3fd',1,'css_size():&#160;param_pcmn.inc.php'],['../anc__key__input_8php.html#a98cad3d8db25bafe71d8df1839591c31',1,'css_size():&#160;anc_key_input.php']]],
   ['customer',['Customer',['../classCustomer.html',1,'']]],
   ['customer_2einc_2ephp',['customer.inc.php',['../customer_8inc_8php.html',1,'']]]
 ];
