@@ -4,7 +4,7 @@ var searchData=
   ['navigation_5fbar',['navigation_bar',['../user__common_8php.html#ad1c880345ee627b431729c8fa77f2abb',1,'user_common.php']]],
   ['nb',['nb',['../ac__common_8php.html#ae2cf76b42d69a20eab06316c6369c33e',1,'ac_common.php']]],
   ['nbm',['nbm',['../ac__common_8php.html#a8380d6c0142438e5c34ff1f97a59a31b',1,'ac_common.php']]],
-  ['next',['next',['../classPhpcompta__SQL.html#affdcc7157890abefb8e8eafdb89e4dca',1,'Phpcompta_SQL']]],
+  ['next',['next',['../classNoalyss__SQL.html#a51a23fbb8d4626bb0dad487a4a4a1d0e',1,'Noalyss_SQL']]],
   ['next_5fnumber',['next_number',['../classAcc__Ledger.html#a1ff7fde87d17e03f7b50753d2721a146',1,'Acc_Ledger']]],
   ['noaccess',['NoAccess',['../ac__common_8php.html#abe8345e3dd8b6011e51f258ae7808348',1,'ac_common.php']]],
   ['num_5frow',['num_row',['../classDatabase.html#a84efe80575a615cab05f251eb9912b3b',1,'Database']]],
