@@ -2,7 +2,7 @@ var searchData=
 [
   ['label',['label',['../ajax__view__mod__stock_8php.html#a637f53125c1da97e0f43ee8292856e3c',1,'label():&#160;ajax_view_mod_stock.php'],['../card__attr_8inc_8php.html#a2b31ea3a09d6aa5c1ef435c15bdb7ef3',1,'label():&#160;card_attr.inc.php'],['../export__balance__csv_8php.html#a22f45a3cb4f074e609f58ebaeef0ecf9',1,'label():&#160;export_balance_csv.php'],['../extension_8inc_8php.html#a160fc28d88d09c4c962bbe4eb11c38b3',1,'label():&#160;extension.inc.php'],['../fiche_8inc_8php.html#a7968608e0aecebf2c9551c3d6e93b07b',1,'label():&#160;fiche.inc.php'],['../impress__poste_8inc_8php.html#a637f53125c1da97e0f43ee8292856e3c',1,'label():&#160;impress_poste.inc.php']]],
   ['layer',['layer',['../acc__ledger_8js.html#a5873be43f1507a633b5fc8eb1cd9c11b',1,'acc_ledger.js']]],
-  ['left',['left',['../action__search_8php.html#a361a2bf748f322798d4f19476600f204',1,'left():&#160;action_search.php'],['../param__jrn_8php.html#a0121b967115b33286d071cd0a38ffc2d',1,'left():&#160;param_jrn.php']]],
+  ['left',['left',['../action__search_8php.html#a361a2bf748f322798d4f19476600f204',1,'action_search.php']]],
   ['line_5fcolor',['line_color',['../securimage__show_8php.html#ab9305e61f284e63bb6444d4e36f077c6',1,'line_color():&#160;securimage_show.php'],['../securimage__show__example_8php.html#ab9305e61f284e63bb6444d4e36f077c6',1,'line_color():&#160;securimage_show_example.php'],['../securimage__show__example2_8php.html#ab9305e61f284e63bb6444d4e36f077c6',1,'line_color():&#160;securimage_show_example2.php']]],
   ['logger',['Logger',['../unittest_8js.html#a05b2a3850dc6e466051d902956aab133',1,'unittest.js']]]
 ];
