@@ -2,6 +2,8 @@ var searchData=
 [
   ['offsetx',['offsetX',['../infobulle_8js.html#ac169ab7c3580fc507c64c4227d242eb3',1,'infobulle.js']]],
   ['offsety',['offsetY',['../infobulle_8js.html#ae2f741618af145cd14a4a0825f065a3f',1,'infobulle.js']]],
+  ['old_5fclass',['old_class',['../scripts_8js.html#a4dcd2c7c8273a0842106f5ae86f25ff0',1,'scripts.js']]],
+  ['old_5fselect',['old_select',['../scripts_8js.html#ab50dddf3c6d8defa4bd9177f3019a5fb',1,'scripts.js']]],
   ['onclick',['onclick',['../dashboard_8php.html#afd38dcd34633b790c63f99ce12d2c3c8',1,'dashboard.php']]],
   ['onmousemove',['onmousemove',['../infobulle_8js.html#a6e37a24dc10da1eea1a652beae132503',1,'infobulle.js']]],
   ['op_c3_a9ration',['opération',['../infobulle_8js.html#aa8ee55d156a9739473be7398a4c124fa',1,'infobulle.js']]]
