@@ -28,7 +28,8 @@
     - for reconcialiation
     - update of analytic content
 */
-define ('ALLOWED',1);
+if ( ! defined('ALLOWED')) define ('ALLOWED',1);
+
 require_once '../include/constant.php';
 require_once('class_database.php');
 require_once('class_user.php');
@@ -63,7 +64,24 @@ ajax_disconnected($div);
 
 $cn=new Database(dossier::id());
 $g_parameter=new Own($cn);
-
+if ( LOGINPUT)
+    {
+        $file_loginput=fopen($_ENV['TMP'].'/scenario-'.$_SERVER['REQUEST_TIME'].'.php','a+');
+        fwrite ($file_loginput,"<?php \n");
+        fwrite ($file_loginput,'//@description:'.$action."\n");
+        fwrite($file_loginput, '$_GET='.var_export($_GET,true));
+        fwrite($file_loginput,";\n");
+        fwrite($file_loginput, '$_POST='.var_export($_POST,true));
+        fwrite($file_loginput,";\n");
+        fwrite($file_loginput, '$_POST[\'gDossier\']=$gDossierLogInput;');
+        fwrite($file_loginput,"\n");
+        fwrite($file_loginput, '$_GET[\'gDossier\']=$gDossierLogInput;');
+        fwrite($file_loginput,"\n");
+        fwrite($file_loginput,' $_REQUEST=array_merge($_GET,$_POST);');
+        fwrite($file_loginput,"\n");
+         fwrite($file_loginput,"include '".basename(__FILE__)."';\n");
+        fclose($file_loginput);
+    }
 // check if the user is valid and can access this folder
 global $g_user;
 $g_user=new User($cn);
@@ -104,7 +122,7 @@ if ($ledger=="")
     ob_end_clean();
 
     $html=escape_xml($html);
-    header('Content-type: text/xml; charset=UTF-8');
+    if ( ! headers_sent()) {     header('Content-type: text/xml; charset=UTF-8');} else { echo "HTML".unescape_xml($html);}
     echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
 <data>
@@ -493,6 +511,12 @@ case 'save':
             //////////////////////////////////////////////////////////////////
             $op->save_info($_POST['OTHER'],'OTHER');
             $op->save_info($_POST['BON_COMMANDE'],'BON_COMMANDE');
+            ///////////////////////////////////////////////////////////////////
+            // Save related
+            //////////////////////////////////////////////////////////////////
+            $related=HtmlInput::default_value_post("related", "0");
+            if ($related == "0" )                throw new Exception('Parameter not send -> related'.__FILE__.__LINE__,10);
+            $op->insert_related_action($related);
 
         }
         echo _('Opération sauvée');
@@ -556,8 +580,9 @@ case 'reverseop':
     break;
 }
 $html=escape_xml($html);
-header('Content-type: text/xml; charset=UTF-8');
-echo <<<EOF
+ if ( ! headers_sent()) {     header('Content-type: text/xml; charset=UTF-8');} else { echo "HTML".unescape_xml($html);}
+ 
+ echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
 <data>
 <ctl>$div</ctl>
