@@ -34,7 +34,8 @@
  * dl : display form to modify, add and delete lettering for a given operation
  *
  */
-define ('ALLOWED',1);
+if ( ! defined('ALLOWED')) define ('ALLOWED',1);
+
 require_once '../include/constant.php';
 require_once('class_database.php');
 require_once ('class_fiche.php');
@@ -69,6 +70,24 @@ if ($gDossier<>0) {
 }
 $html = var_export($_REQUEST, true);
 
+if ( LOGINPUT)
+    {
+        $file_loginput=fopen($_ENV['TMP'].'/scenario-'.$_SERVER['REQUEST_TIME'].'.php','a+');
+        fwrite ($file_loginput,"<?php \n");
+        fwrite ($file_loginput,'//@description:'.$op."\n");
+        fwrite($file_loginput, '$_GET='.var_export($_GET,true));
+        fwrite($file_loginput,";\n");
+        fwrite($file_loginput, '$_POST='.var_export($_POST,true));
+        fwrite($file_loginput,";\n");
+        fwrite($file_loginput, '$_POST[\'gDossier\']=$gDossierLogInput;');
+        fwrite($file_loginput,"\n");
+        fwrite($file_loginput, '$_GET[\'gDossier\']=$gDossierLogInput;');
+        fwrite($file_loginput,"\n");
+        fwrite($file_loginput,' $_REQUEST=array_merge($_GET,$_POST);');
+        fwrite($file_loginput,"\n");
+        fwrite($file_loginput,"include '".basename(__FILE__)."';\n");
+        fclose($file_loginput);
+    }
 switch ($op)
 {
 	case "remove_anc":
@@ -187,7 +206,7 @@ EOF;
 		$Max = Database::num_row($Res);
 		$r = "";
 		$r = HtmlInput::anchor_close('tva_select');
-		$r.=h2(_('Choississez la TVA '),'class="title"');
+		$r.=h2(_('Choisissez la TVA '),'class="title"');
 		$r.='<div >';
 		$r.= '<TABLE style="width:100%">';
 		$r.=th('');
@@ -632,6 +651,25 @@ EOF;
             }
             exit();
             break;
+        
+        case 'anc_key_choice': 
+            /*
+             *  Show the available distribution keys for analytic 
+             */
+            require_once 'ajax_anc_key_choice.php';
+            break;
+        case 'anc_key_compute':
+            /* 
+             * Show the activities computed with the selected distribution key 
+             */
+            require_once 'ajax_anc_key_compute.php';
+            break;
+        case 'account_update':
+            /**
+             * update an accounting (from CFGPCMN)
+             */
+            require_once 'ajax_account_update.php';
+            break;
 	default:
 		var_dump($_GET);
 }
