@@ -203,11 +203,12 @@ if ( strlen(domaine) > 0 )
 
 echo '
 <span style="background-color:#879ed4;color:white;padding-left:4px;padding-right:4px;">
-version  6.7.2.0 - '.$my_domain.'
+version  6.8.0.0 - '.$my_domain.'
 </span>
 <BR>
 <BR>
 <BR>
+
 <BR>
 <center>
 <IMG SRC="image/logo6720.png" alt="NOALYSS">
@@ -264,12 +265,16 @@ echo '
 </table>
 
 </form>
-</Center>
-<div  style="position:absolute;bottom:0em;border:1px solid red;text-align:right;width:20em;">
-<span style="display:block">Pour une meilleure expérience web, nous vous conseillons <a href="http://www.mozilla.com/fr/">firefox</a></span>
-<span style="display:block">For a better web experience, we recommend you <a href="http://www.mozilla.com/en/">firefox</a></span>
+<div style="position:absolute;bottom: 0px;width:80%;right:10%">
+    <p>Nous conseillons d'utiliser Firefox ou chrome.</p>
+    <p>We recommend to use Firefox or Chrome.</p>
+<ul style="list-style:none;display:block">
+    <li style="display:inline"> <a href="https://www.mozilla.org/fr/firefox/new/"> <img border="0" width="128px" src="image/header-firefox.png"></a></li>
+<li style="display:inline"><a href="https://www.google.fr/chrome/browser/desktop/"> <img border="0" width="128px" src="image/chrome_logo_2x.png"></a></li>
+</ul>
 </div>
  <script> SetFocus('p_user'); </script>
+
 </body>
 </html>
 
