@@ -342,10 +342,12 @@ function ledger_fin_add_row()
 
 /**
  * @brief add a line in the form for the purchase ledger
+ * @param p_dossier folder id
+ * @param p_table_name
  */
 function ledger_add_row()
 {
-	try{
+    try{
     style='class="input_text"';
     var mytable=g("sold_item").tBodies[0];
     var ofirstRow=mytable.rows[1];
@@ -366,18 +368,17 @@ function ledger_add_row()
         new_tt.evalScripts();
     }
 
-    g("e_march"+nb.value+"_label").innerHTML='&nbsp;';
-    g("e_march"+nb.value+"_label").value='';
-    g("e_march"+nb.value+"_price").value='0';
-    g("e_march"+nb.value).value="";
-    g("e_quant"+nb.value).value="1";
-    if ($("e_march"+nb.value+"_tva_amount")) g("e_march"+nb.value+"_tva_amount").value=0;
+    $("e_march"+nb.value+"_label").innerHTML='';
+    $("e_march"+nb.value+"_label").value='';
+    $("e_march"+nb.value+"_price").value='0';
+    $("e_march"+nb.value).value="";
+    $("e_quant"+nb.value).value="1";
+    if ($("e_march"+nb.value+"_tva_amount")) $("e_march"+nb.value+"_tva_amount").value=0;
 
     nb.value++;
 
     new_tt.evalScripts();
 	} catch(e) {alert(e.message);}
-
 }
 /**
  * @brief compute the sum of a purchase, update the span tvac, htva and tva
@@ -645,8 +646,6 @@ function view_history_account(p_value,dossier)
 					{
 						success_box(req,xml);
 						g(id).style.top=calcy(140+(layer*3))+"px";
-						g(id).style.left="10%";
-						g(id).style.width='80%';
 					}
                    }
                );
@@ -667,8 +666,6 @@ function update_history_account(obj)
 					{
 						success_box(req,xml);
 						g(obj.div).style.top=calcy(140+(layer*3))+"px";
-						g(obj.div).style.left="10%";
-						g(obj.div).style.width='80%';
 					}
 	    });
     } catch (e)
@@ -703,8 +700,6 @@ var popup={'id':
 					{
 						success_box(req,xml);
 						g(id).style.top=calcy(140+(layer*3))+"px";
-						g(id).style.left="10%";
-						g(id).style.width='80%';
 					}
                    }
                );
@@ -724,8 +719,6 @@ function update_history_card(obj)
 					{
 						success_box(req,xml);
 						g(obj.div).style.top=calcy(140+(layer*3))+"px";
-						g(obj.div).style.left="10%";
-						g(obj.div).style.width='80%';
 					}
 	    });
     } catch (e)
@@ -804,8 +797,6 @@ function modifyOperation(p_value, dossier)
 					success_box(xml, txt);
                                         $(id).style.position="absolute";
 					$(id).style.top = calcy(100 + (layer * 3))+"px";
-					g(id).style.left = '10%';
-					g(id).style.width = "80%";
 				}
 			}
 	);
@@ -865,7 +856,7 @@ function dsp_letter(obj)
 {
     try
     {
-        var queryString='gDossier='+obj.gDossier+'&j_id='+obj.j_id+'&op=dl'+'&ot='+this.obj_type;
+        var queryString='gDossier='+obj.gDossier+'&j_id='+obj.j_id+'&op=dl'+'&ot='+obj.obj_type;
         var action=new Ajax.Request(
                        "ajax_misc.php",
                        {
@@ -994,8 +985,8 @@ function op_save(obj)
                                   parameters:queryString,
                                   onFailure:null,
                                   onSuccess:infodiv
-                                      }
-                                    );
+                                               }
+                            );
     }
     return false;
 	} catch (e)
