@@ -94,18 +94,10 @@ function search_card(obj)
 	if (  $('search_card') ) {
 	    removeDiv('search_card');
 	}
-	var sx=0;
-	if ( window.scrollY)
-	{
-            sx=window.scrollY+40;
-	}
-	else
-	{
-            sx=document.body.scrollTop+60;
-	}
-
-	var div_style="top:"+sx+"px;height:80%";
-	add_div({id:'search_card',cssclass:'inner_box',html:loading(),style:div_style,drag:true});
+	
+	
+        waiting_box();
+	
 
         var action=new Ajax.Request ( 'ajax_card.php',
                                       {
@@ -121,6 +113,106 @@ function search_card(obj)
         alert('search_card failed'+e.message);
     }
 }
+/**
+ *@brief Display form for select card to add to action : other_concerned
+ *action_add_concerned_card
+ */
+function action_add_concerned_card(obj)
+{
+    try
+    {
+        var dossier = 0;
+        var inp="";
+        var ag_id=0;
+        
+        if (obj.dossier) {
+            dossier = obj.dossier; /* From the button */
+        } 
+        if (obj.ag_id) {
+            ag_id=obj.ag_id;
+        }
+        /* from the form */
+        if (obj.elements) {
+            if (obj.elements['gDossier']) 
+            {
+                dossier = obj.elements['gDossier'].value;
+            }
+
+            if (obj.elements['query']) {
+                inp = obj.elements['query'].value;
+            }
+
+            if (obj.elements['ag_id']) {
+                ag_id = obj.elements['ag_id'].value;
+            }
+        }
+        if (dossier == 0) {
+            throw "obj.dossier not found";
+        }
+        if (ag_id == 0) {
+            throw "obj.ag_id not found";
+        }
+        var query = encodeJSON({
+            'gDossier': dossier,
+            'op': 'action_add_concerned_card',
+            'query' : inp,
+            'ctl' : 'unused',
+            'ag_id' : ag_id
+        });
+
+        waiting_box();
+
+
+        var action = new Ajax.Request('ajax_card.php',
+                {
+                    method: 'get',
+                    parameters: query,
+                    onFailure: errorFid,
+                    onSuccess: function (req, txt)
+                    {
+                        try {
+                        remove_waiting_box();
+                        var answer = req.responseXML;
+                        var a = answer.getElementsByTagName('ctl');
+                        if (a.length == 0)
+                        {
+                            var rec = req.responseText;
+                            alert('erreur :' + rec);
+                        }
+                        var html = answer.getElementsByTagName('code');
+                        var namectl = a[0].firstChild.nodeValue;
+                        var nodeXml = html[0];
+                        var code_html = getNodeText(nodeXml);
+                        code_html = unescape_xml(code_html);
+
+                        var sx = 0;
+                        if (window.scrollY)
+                        {
+                            sx = window.scrollY + 40;
+                        }
+                        else
+                        {
+                            sx = document.body.scrollTop + 60;
+                        }
+                        var div_style = "top:" + sx + "px;height:80%";
+                        if ( ! $('search_card')) { add_div({id: 'search_card', cssclass: 'inner_box', html: "", style: div_style, drag: true}); }
+                        $('search_card').innerHTML = code_html;
+                        $('query').focus();
+                        }catch (e) {
+                            alert(e.message);
+                        }
+                    }
+                }
+        );
+    }
+    catch (e)
+    {
+        alert('search_card failed' + e.message);
+        return false;
+    }
+    return false;
+}
+
 /**
  *@brief when you submit the form for searching a card
  *@param obj form
@@ -184,6 +276,8 @@ function result_card_search(req)
 {
     try
     {
+        
+        remove_waiting_box();
         var answer=req.responseXML;
         var a=answer.getElementsByTagName('ctl');
         if ( a.length == 0 )
@@ -197,7 +291,21 @@ function result_card_search(req)
         var nodeXml=html[0];
         var code_html=getNodeText(nodeXml);
         code_html=unescape_xml(code_html);
+        
+        var sx=0;
+	if ( window.scrollY)
+	{
+            sx=window.scrollY+40;
+	}
+	else
+	{
+            sx=document.body.scrollTop+60;
+	}
+
+        var div_style="top:"+sx+"px;height:80%";
+        add_div({id:'search_card',cssclass:'inner_box',html:"",style:div_style,drag:true,effect:'blinddown'});
         $('search_card').innerHTML=code_html;
+        $('query').focus();
     }
     catch (e)
     {
@@ -433,16 +541,16 @@ function select_card_type(obj)
     var sx=0;
     if ( window.scrollY)
     {
-            sx=window.scrollY+40;
+            sx=window.scrollY+160;
     }
     else
     {
-        sx=document.body.scrollTop+60;
+        sx=document.body.scrollTop+160;
     }
 
-    var str_style="top:"+sx+"px;left:25%;height:30%";
-
-    var popup={'id':  content,'cssclass':'inner_box','style':str_style,'html':loading(),'drag':true};
+    var str_style="top:"+sx+"px;height:auto";
+    waiting_box();
+    var popup={'id':  content,'cssclass':'inner_box','style':str_style,'html':"",'drag':true};
 
     add_div(popup);
 
@@ -477,7 +585,11 @@ function select_card_type(obj)
                                   method:'get',
                                   parameters:queryString,
                                   onFailure:errorFid,
-                                  onSuccess:fill_box
+                                  onSuccess:function(req) { 
+                                   
+                                      fill_box(req);
+                                       $('lk_cat_card_table').focus();
+                                    }
                                   }
                                 );
 }
@@ -504,7 +616,7 @@ function dis_blank_card(obj)
         ref='&ref';
     }
     var content='div_new_card';
-    var nTop=calcy(30);
+    var nTop=calcy(150);
     var nLeft=posX;
     var str_style="top:"+nTop+"px;right:"+nLeft+"px;height:auto";
 
@@ -718,3 +830,77 @@ try {
 	return false;
     }
 }
+/***
+ * In Follow-up, update, it is possible to add several card as concerned person or company
+ * this function save it into the database, display the result and remove the search_card div
+ * @param {type} p_dossier dossier
+ * @param {type} p_fiche_id fiche.f_id
+ * @param {type} p_action_id action_gestion.ag_id
+ * @returns {undefined} nothing
+ */
+function action_save_concerned(p_dossier, p_fiche_id, p_action_id) {
+    var query = encodeJSON({'gDossier': p_dossier, 'f_id': p_fiche_id, 'ag_id': p_action_id,'op':'action_save_concerned','ctl':'unused'});
+    var a=new Ajax.Request('ajax_card.php',
+            {
+                method: 'get',
+                parameters: query,
+                onFailure: errorFid,
+                onSuccess: function (req, txt)
+                {
+                    try {
+                        remove_waiting_box();
+                        var answer = req.responseXML;
+                        var a = answer.getElementsByTagName('ctl');
+                        if (a.length == 0)
+                        {
+                            var rec = req.responseText;
+                            alert('erreur :' + rec);
+                        }
+                        var html = answer.getElementsByTagName('code');
+                        var namectl = a[0].firstChild.nodeValue;
+                        var nodeXml=html[0];
+                        var code_html = getNodeText(nodeXml);
+                        code_html = unescape_xml(code_html);
+                        removeDiv('search_card');
+                        $('concerned_card_td').innerHTML = code_html;
+                    } catch (e) {
+                       
+                    }
+                }
+            }
+    );
+    }
+function action_remove_concerned(p_dossier,p_fiche_id,p_action_id)
+{
+ var query = encodeJSON({'gDossier': p_dossier, 'f_id': p_fiche_id, 'ag_id': p_action_id,'op':'action_remove_concerned','ctl':'unused'});
+    var a=new Ajax.Request('ajax_card.php',
+            {
+                method: 'get',
+                parameters: query,
+                onFailure: errorFid,
+                onSuccess: function (req, txt)
+                {
+                    try {
+                        remove_waiting_box();
+                        var answer = req.responseXML;
+                        var a = answer.getElementsByTagName('ctl');
+                        if (a.length == 0)
+                        {
+                            var rec = req.responseText;
+                            alert('erreur :' + rec);
+                        }
+                        var html = answer.getElementsByTagName('code');
+                        var namectl = a[0].firstChild.nodeValue;
+                        var nodeXml=html[0];
+                        var code_html = getNodeText(nodeXml);
+                        code_html = unescape_xml(code_html);
+                        removeDiv('search_card');
+                        $('concerned_card_td').innerHTML = code_html;
+                    } catch (e) {
+                        if ( console) { console.log('Erreur ') + e.message;}
+                    }
+                }
+            }
+    );
+    }
+    
\ No newline at end of file
