@@ -121,7 +121,7 @@ function enable_type_periode()
     if ($("type_periode").options[$("type_periode").selectedIndex].value == 0)
     {
         $('from_periode').enable();
-        $('to_periode').enable ();
+        $('to_periode').enable();
         $('from_date').disable();
         $('to_date').disable();
         $('p_step').enable();
@@ -129,7 +129,7 @@ function enable_type_periode()
     else
     {
         $('from_periode').disable();
-        $('to_periode').disable ();
+        $('to_periode').disable();
         $('from_date').enable();
         $('to_date').enable();
         $('p_step').disable();
@@ -343,7 +343,7 @@ function getNodeText(xmlNode)
  */
 function change_month(obj)
 {
-    var queryString = "gDossier=" + obj.gDossier + "&op=cal" + "&per=" + obj.value+"&t="+obj.type_display;
+    var queryString = "gDossier=" + obj.gDossier + "&op=cal" + "&per=" + obj.value + "&t=" + obj.type_display;
     var action = new Ajax.Request(
             "ajax_misc.php", {method: 'get', parameters: queryString, onFailure: ajax_misc_failure, onSuccess: success_misc}
     );
@@ -427,7 +427,7 @@ function cat_doc_change(p_dt_id, p_dossier)
             {
                 method: 'get', parameters: queryString,
                 onFailure: ajax_misc_failure,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
                     add_div({id: 'change_doc_div', style: str_style, cssclass: 'inner_box', drag: "1"});
                     $('change_doc_div').innerHTML = req.responseText;
@@ -475,24 +475,48 @@ function popup_select_tva(obj)
             removeDiv('tva_select');
         }
 
-
-        var nTop = posY - 50;
-        var nLeft = "35%";
-        var str_style = "top:" + nTop + "px;left:" + nLeft + ";width:55em;height:auto";
-
-        var popup = {'id': 'tva_select', 'cssclass': 'inner_box', 'style': str_style, 'html': loading(), 'drag': true};
-        add_div(popup);
         var queryString = "gDossier=" + obj.gDossier + "&op=dsp_tva" + "&ctl=" + obj.ctl + '&popup=' + 'tva_select';
         if (obj.jcode)
             queryString += '&code=' + obj.jcode;
         if (obj.compute)
             queryString += '&compute=' + obj.compute;
+
         var action = new Ajax.Request(
                 "ajax_misc.php",
                 {method: 'get',
                     parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: success_popup_select_tva
+                    onSuccess: function (req)
+                    {
+                        try
+                        {
+                            var answer = req.responseXML;
+                            var popup = answer.getElementsByTagName('popup');
+                            if (popup.length === 0)
+                            {
+                                var rec = req.responseText;
+                                alert('erreur :' + rec);
+                            }
+                            var html = answer.getElementsByTagName('code');
+
+                            var name_ctl = popup[0].firstChild.nodeValue;
+                            var nodeXml = html[0];
+                            var code_html = getNodeText(nodeXml);
+                            code_html = unescape_xml(code_html);
+
+                            var nTop = posY - 200;
+                            var nLeft = "15%";
+                            var str_style = "top:" + nTop + "px;left:" + nLeft + ";right:" + nLeft + ";width:55em;height:auto";
+
+                            var popup = {'id': 'tva_select', 'cssclass': 'inner_box', 'style': str_style, 'html': code_html, 'drag': true};
+                            add_div(popup);
+
+                        }
+                        catch (e)
+                        {
+                            alert("success_popup_select_tva " + e.message);
+                        }
+                    }
                 }
         );
     }
@@ -503,30 +527,11 @@ function popup_select_tva(obj)
 }
 /**
  *@brief display the popup with vat and explanations
+ *@obsolete
  */
-function success_popup_select_tva(req)
+function success_popup_select_tva_obsolete(req)
 {
-    try
-    {
-        var answer = req.responseXML;
-        var popup = answer.getElementsByTagName('popup');
-        if (popup.length === 0)
-        {
-            var rec = req.responseText;
-            alert('erreur :' + rec);
-        }
-        var html = answer.getElementsByTagName('code');
 
-        var name_ctl = popup[0].firstChild.nodeValue;
-        var nodeXml = html[0];
-        var code_html = getNodeText(nodeXml);
-        code_html = unescape_xml(code_html);
-        $(name_ctl).innerHTML = code_html;
-    }
-    catch (e)
-    {
-        alert("success_popup_select_tva " + e.message);
-    }
 
 }
 
@@ -586,8 +591,9 @@ function success_set_tva_label(req)
  *@brief set loading for waiting
  *@param name of ipopup
  *@see showIPopup
+ *@obsolete
  */
-function set_wait(name)
+function set_wait_obsolete(name)
 {
     var content = name + "_content";
     $(content).innerHTML = 'Un instant...<image src="image/loading.gif" border="0" alt="Chargement...">';
@@ -641,14 +647,18 @@ function add_div(obj)
 
         var bottom_div = document.body;
         bottom_div.appendChild(elt);
+        /* if ( obj.effect && obj.effect != 'none' ) { Effect.Grow(obj.id,{direction:'top-right',duration:0.1}); }
+         else if ( ! obj.effect ){ Effect.Grow(obj.id,{direction:'top-right',duration:0.1}); }*/
         if (obj.drag)
         {
-            new Draggable(obj.id, {starteffect: function()
+            new Draggable(obj.id, {starteffect: function ()
                 {
                     new Effect.Highlight(obj.id, {scroll: window, queue: 'end'});
                 }}
             );
         }
+        /* elt.setStyle({visibility:'visible'}); */
+        elt.style.visibility='visible';
     }
     catch (e)
     {
@@ -681,13 +691,14 @@ function removeDiv(elt)
 function waiting_box()
 {
     obj = {
-        id: 'wait_box', html: '<h2 class="title">Chargement</h2>'+loading()
+        id: 'wait_box', html: '<h2 class="title">Chargement</h2>' + loading()
     };
-    var y = calcy(posY);
-    obj.style = fixed_position(posX, y) + ";width:200px";
+    var y = fixed_position(10, 250)
+    obj.style = y + ";width:20%;margin-left:40%;";
     if ($('wait_box')) {
         removeDiv('wait_box');
     }
+    obj.effect = 'none';
     add_div(obj);
     $('info_div').innerHTML = 'Un instant';
     $('info_div').style.display = "block";
@@ -719,7 +730,7 @@ function show_box(obj)
         {
             sx = document.body.scrollTop + 40;
         }
-        g(obj.id).style.top = sx+"px";
+        g(obj.id).style.top = sx + "px";
         show(obj.id);
     }
     else
@@ -761,9 +772,7 @@ function success_box(req, json)
         g(name_ctl).innerHTML = code_html;
         g(name_ctl).style.height = 'auto';
 
-        if (name_ctl != 'popup')
-            g(name_ctl).style.width = '60%';
-        else
+        if (name_ctl == 'popup')
             g(name_ctl).style.width = 'auto';
     }
     catch (e)
@@ -782,7 +791,7 @@ function success_box(req, json)
 
 function error_box()
 {
-    alert('IBOX : error_box ajax not implemented');
+    alert('[error_box] ajax not implemented');
 }
 /**
  * show the ledger choice
@@ -794,17 +803,17 @@ function show_ledger_choice(json_obj)
         waiting_box();
         var i = 0;
         var query = "gDossier=" + json_obj.dossier + '&type=' + json_obj.type + '&div=' + json_obj.div + '&op=ledger_show';
-        query = query + '&nbjrn=' + $( json_obj.div+'nb_jrn').value;
+        query = query + '&nbjrn=' + $(json_obj.div + 'nb_jrn').value;
         query = query + '&all_type=' + json_obj.all_type;
-        for (i = 0; i < $( json_obj.div+'nb_jrn').value; i++) {
-            query = query + "&r_jrn[]=" + $( json_obj.div+'r_jrn[' + i + ']').value;
+        for (i = 0; i < $(json_obj.div + 'nb_jrn').value; i++) {
+            query = query + "&r_jrn[]=" + $(json_obj.div + 'r_jrn[' + i + ']').value;
         }
         var action = new Ajax.Request(
                 "ajax_misc.php",
                 {method: 'get',
                     parameters: query,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, json) {
+                    onSuccess: function (req, json) {
                         try {
                             var obj = {
                                 id: json_obj.div + 'jrn_search',
@@ -813,13 +822,14 @@ function show_ledger_choice(json_obj)
                                 drag: 1
                             };
                             //var y=calcy(posY);
-                            var y=posY;
-                           if (json_obj.div != '')obj.cssclass="";
-                            obj.style="top:"+y+'px;'+obj.style;
-                           /* if ( json_obj.class ) 
-                            { 
-                                obj.cssclass=json_obj.class;
-                            }*/
+                            var y = posY;
+                            if (json_obj.div != '')
+                                obj.cssclass = "";
+                            obj.style = "top:" + y + 'px;' + obj.style;
+                            /* if ( json_obj.class ) 
+                             { 
+                             obj.cssclass=json_obj.class;
+                             }*/
                             add_div(obj);
 
 
@@ -853,7 +863,7 @@ function show_ledger_choice(json_obj)
                 }
         );
     } catch (e) {
-        alert('show_ledger_choice'+e.message);
+        alert('show_ledger_choice' + e.message);
     }
 }
 /**
@@ -869,21 +879,21 @@ function hide_ledger_choice(p_frm_search)
         var str = "";
         var name = "";
         var n_name = "";
-        var sel=0;
+        var sel = 0;
         for (i = 0; i < nb; i++) {
-            n_name = div + "r_jrn[" + sel+"]";
+            n_name = div + "r_jrn[" + sel + "]";
             name = div + "r_jrn" + i;
             if ($(name).checked) {
                 str += '<input type="hidden" id="' + n_name + '" name="' + n_name + '" value="' + $(name).value + '">';
                 sel++;
             }
         }
-        str += '<input type="hidden" name="'+div+'nb_jrn" id="'+div+'nb_jrn" value="' + sel + '">';
-        $('ledger_id'+div).innerHTML = str;
-        removeDiv(div+'jrn_search');
+        str += '<input type="hidden" name="' + div + 'nb_jrn" id="' + div + 'nb_jrn" value="' + sel + '">';
+        $('ledger_id' + div).innerHTML = str;
+        removeDiv(div + 'jrn_search');
         return false;
     } catch (e) {
-        alert('hide_ledger_choice'+e.message);
+        alert('hide_ledger_choice' + e.message);
         return false;
     }
 
@@ -1032,8 +1042,8 @@ function display_periode(p_dossier, p_id)
                     onSuccess: success_display_periode
                 }
         );
-        $('mod_periode').style.top = (posY - 70)+"px";
-        $('mod_periode').style.left = (posX - 70)+"px";
+        $('mod_periode').style.top = (posY - 70) + "px";
+        $('mod_periode').style.left = (posX - 70) + "px";
     }
     catch (e)
     {
@@ -1146,7 +1156,7 @@ function mod_predf_op(dossier_id, od_id)
     removeDiv(target);
     var sx = '20%';
     var sy = '10%';
-    var str_style = "top:" + sx + ";left:" + sy+";";
+    var str_style = "top:" + sx + ";left:" + sy + ";";
 
     var div = {id: target, cssclass: 'inner_box', style: str_style, html: loading(), drag: 1};
 
@@ -1181,11 +1191,18 @@ function save_predf_op(obj)
 
     return false;
 }
+
 /**
  *ctl_concern is the widget to update
- *amount_id is either a html obj. or an amount
+ *amount_id is either a html obj. or an amount and the field tiers if given
+ * @param {type} dossier
+ * @param {type} ctl_concern
+ * @param {type} amount_id
+ * @param {type} ledger
+ * @param {type} p_id_target
+ * @returns {undefined}
  */
-function search_reconcile(dossier, ctl_concern, amount_id, ledger)
+function search_reconcile(dossier, ctl_concern, amount_id, ledger, p_id_target)
 {
     var dossier = g('gDossier').value;
     if (amount_id === undefined)
@@ -1208,17 +1225,17 @@ function search_reconcile(dossier, ctl_concern, amount_id, ledger)
     removeDiv(target);
     var str_style = fixed_position(77, 99);
     str_style += ";width:92%;overflow:auto;";
+    waiting_box();
 
-    var div = {id: target, cssclass: 'inner_box', style: str_style, html: loading(), drag: 1};
-
-    add_div(div);
+    
     var target = {gDossier: dossier,
         ctlc: ctl_concern,
         op: 'search_op',
         ctl: target,
         ac: 'JSSEARCH',
         amount_id: amount_id,
-        ledger: ledger};
+        ledger: ledger,
+        target: p_id_target};
 
     var qs = encodeJSON(target);
 
@@ -1227,8 +1244,10 @@ function search_reconcile(dossier, ctl_concern, amount_id, ledger)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
+                    var div = {id: 'search_op', cssclass: 'inner_box', style: str_style, drag: 1};
+                    add_div(div);
                     $('search_op').innerHTML = req.responseText;
                     req.responseText.evalScripts();
                 }
@@ -1250,7 +1269,7 @@ function search_operation(obj)
                     method: 'get',
                     parameters: qs,
                     onFailure: null,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         $('search_op').innerHTML = req.responseText;
                         req.responseText.evalScripts();
@@ -1263,14 +1282,20 @@ function search_operation(obj)
         alert(e.message);
     }
 }
-
+/**
+ * Update the field e_concerned, from class_iconcerned
+ * Value is the field where to put the quick-code but only if one checkbox has been
+ * selected
+ * @param {type} obj
+ * @returns {undefined}
+ */
 function set_reconcile(obj)
 {
 
     try
     {
         var ctlc = obj.elements['ctlc'];
-
+        var target = obj.elements['target'].value;
         for (var e = 0; e < obj.elements.length; e++)
         {
 
@@ -1283,6 +1308,11 @@ function set_reconcile(obj)
                     var nValue = str_name.replace("jr_concerned", "");
                     if ($(ctlc.value).value != '') {
                         $(ctlc.value).value += ',';
+
+                    } else {
+                        if (target != "" && $(target).value == "") {
+                            $(target).value = elmt.value;
+                        }
                     }
                     $(ctlc.value).value += nValue;
                 }
@@ -1310,7 +1340,7 @@ function get_profile_detail(gDossier, profile_id)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
                     $('detail_profile').innerHTML = req.responseText;
                     req.responseText.evalScripts();
@@ -1321,7 +1351,7 @@ function get_profile_detail(gDossier, profile_id)
             }
     );
 }
-function get_profile_detail_success(xml)
+function get_profile_detail_success_obsolete(xml)
 {
     remove_waiting_box();
 
@@ -1362,13 +1392,13 @@ function mod_menu(gdossier, pm_id)
     waiting_box();
     removeDiv('divdm' + pm_id);
     var qs = "op=det_menu&gDossier=" + gdossier + "&pm_id=" + pm_id + "&ctl=divdm" + pm_id;
-    var pos = fixed_position(250, 150);
+    var pos = fixed_position(50, 250);
     var action = new Ajax.Request('ajax_misc.php',
             {
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         add_div({id: "divdm" + pm_id, drag: 1, cssclass: "inner_box", style: pos});
@@ -1394,7 +1424,7 @@ function add_menu(obj)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         add_div({id: "divdm" + p_id, drag: 1, cssclass: "inner_box", style: pos});
@@ -1417,7 +1447,7 @@ function add_plugin(p_dossier)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         var pos = fixed_position(250, 150) + ";width:30%";
@@ -1441,7 +1471,7 @@ function mod_plugin(p_dossier, me_code)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         var pos = fixed_position(250, 150) + ";width:30%";
@@ -1466,7 +1496,7 @@ function create_menu(p_dossier)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         var pos = fixed_position(250, 150) + ";width:30%";
@@ -1495,7 +1525,7 @@ function modify_menu(p_dossier, me_code)
                 method: 'get',
                 parameters: qs,
                 onFailure: null,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         var pos = fixed_position(250, 150) + ";width:30%";
@@ -1564,7 +1594,6 @@ function search_action(dossier, ctl_concern)
         var target = "search_action_div";
         removeDiv(target);
         var str_style = fixed_position(77, 99);
-        str_style += ";width:80%";
 
         var div = {id: target, cssclass: 'inner_box', style: str_style, html: loading(), drag: 1};
 
@@ -1582,7 +1611,7 @@ function search_action(dossier, ctl_concern)
                     method: 'get',
                     parameters: qs,
                     onFailure: null,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         try {
                             remove_waiting_box();
                             $('search_action_div').innerHTML = req.responseText;
@@ -1608,7 +1637,7 @@ function result_search_action(obj)
                 {method: 'get',
                     parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         try {
                             remove_waiting_box();
                             $('search_action_div').innerHTML = req.responseText;
@@ -1671,7 +1700,7 @@ function stock_repo_change(p_dossier, r_id)
     var queryString = "gDossier=" + p_dossier + "&op=mod_stock_repo" + "&r_id=" + r_id;
     var nTop = calcy(posY);
     var nLeft = "200px";
-    var str_style = "top:" + nTop + "px;left:" + nLeft + ";width:50em;height:auto";
+    var str_style = "top:" + nTop + "px;left:" + nLeft + ";height:auto";
 
     removeDiv('change_stock_repo_div');
     waiting_box();
@@ -1680,7 +1709,7 @@ function stock_repo_change(p_dossier, r_id)
             {
                 method: 'get', parameters: queryString,
                 onFailure: ajax_misc_failure,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
                     add_div({id: 'change_stock_repo_div', style: str_style, cssclass: 'inner_box', drag: "1"});
                     $('change_stock_repo_div').innerHTML = req.responseText;
@@ -1693,8 +1722,8 @@ function stock_inv_detail(p_dossier, p_id)
 {
     var queryString = "gDossier=" + p_dossier + "&op=view_mod_stock" + "&c_id=" + p_id + "&ctl=view_mod_stock_div";
     var nTop = calcy(posY);
-    var nLeft = "200px";
-    var str_style = "top:" + nTop + "px;left:" + nLeft + ";width:75%;";
+    var nLeft = "10%";
+    var str_style = "top:" + nTop + "px;left:" + nLeft + ";width:80%;";
 
     removeDiv('view_mod_stock_div');
     waiting_box();
@@ -1703,7 +1732,7 @@ function stock_inv_detail(p_dossier, p_id)
             {
                 method: 'get', parameters: queryString,
                 onFailure: ajax_misc_failure,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
                     add_div({id: 'view_mod_stock_div', style: str_style, cssclass: 'inner_box', drag: "1"});
                     $('view_mod_stock_div').innerHTML = req.responseText;
@@ -1717,21 +1746,21 @@ function show_fin_chdate(obj_id)
     try
     {
         var ch = $(obj_id).options[$(obj_id).selectedIndex].value;
-        if (ch === 2) {
+        if (ch == 2) {
             $('chdate_ext').hide();
             $('thdate').show();
         }
-        if (ch === 1) {
+        if (ch == 1) {
             $('chdate_ext').show();
             $('thdate').hide();
         }
         var nb = $('nb_item').value;
         for (i = 0; i < nb; i++) {
             if ($('tdchdate' + i)) {
-                if (ch === 2) {
+                if (ch == 2) {
                     $('tdchdate' + i).show();
                 }
-                if (ch === 1) {
+                if (ch == 1) {
                     $('tdchdate' + i).hide();
 
                 }
@@ -1768,7 +1797,7 @@ function detail_category_show(p_div, p_dossier, p_id)
             {
                 method: 'get', parameters: queryString,
                 onFailure: ajax_misc_failure,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     remove_waiting_box();
                     $('list_cat_div').hide();
                     $('detail_category_div').innerHTML = req.responseText;
@@ -1832,7 +1861,7 @@ function view_action(ag_id, dossier, modify)
                 method: 'get',
                 parameters: querystring,
                 onFailure: error_box,
-                onSuccess: function(req) {
+                onSuccess: function (req) {
                     try {
                         remove_waiting_box();
                         var answer = req.responseXML;
@@ -1883,6 +1912,7 @@ function filter_table(phrase, _id, colnr, start_row) {
         aCol[0] = colnr;
     }
     var ele;
+    var tot_found = 0;
 
     for (var r = start_row; r < table.rows.length; r++) {
         var found = 0;
@@ -1900,6 +1930,7 @@ function filter_table(phrase, _id, colnr, start_row) {
 
         }
         if (found === 1) {
+            tot_found++;
             table.rows[r].style.display = '';
         } else {
             table.rows[r].style.display = 'none';
@@ -1907,6 +1938,15 @@ function filter_table(phrase, _id, colnr, start_row) {
         $('info_div').style.display = "none";
         $('info_div').innerHTML = "";
     }
+    if (tot_found == 0) {
+        if ($('info_' + _id)) {
+            $('info_' + _id).innerHTML = " Aucun résultat ";
+        }
+    } else {
+        if ($('info_' + _id)) {
+            $('info_' + _id).innerHTML = "  ";
+        }
+    }
 }
 /**
  * @brief
@@ -1914,13 +1954,14 @@ function filter_table(phrase, _id, colnr, start_row) {
  */
 function display_task(p_id)
 {
-    new Draggable(p_id, {starteffect: function()
+    new Draggable(p_id, {starteffect: function ()
         {
             new Effect.Highlight(obj.id, {scroll: window, queue: 'end'});
         }}
     );
-    $(p_id).style.top = posY+'px';
-    $(p_id).style.left = posX+'px';
+    $(p_id).style.top = posY + 'px';
+    $(p_id).style.left = "10%";
+    $(p_id).style.width = "80%";
     $(p_id).style.display = 'block';
 
 }
@@ -1954,7 +1995,7 @@ function ask_navigator(p_dossier) {
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         add_div({id: 'navi_div', style: 'top:2em;left:2em;width:90%', cssclass: 'inner_box'});
                         $('navi_div').innerHTML = req.responseText;
@@ -1990,7 +2031,7 @@ function set_preference(p_dossier) {
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         add_div({id: 'preference_div', drag: 1});
                         $('preference_div').innerHTML = req.responseText;
@@ -2027,7 +2068,7 @@ function show_bookmark(p_dossier) {
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         add_div({id: 'bookmark_div', cssclass: 'inner_box', drag: 1});
                         $('bookmark_div').innerHTML = req.responseText;
@@ -2060,7 +2101,7 @@ function save_bookmark() {
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         // removeDiv('bookmark_div');
                         // 
@@ -2094,7 +2135,7 @@ function remove_bookmark() {
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         remove_waiting_box();
                         $('bookmark_div').innerHTML = req.responseText;
                         try
@@ -2137,7 +2178,7 @@ function show_tag(p_dossier, p_ac, p_tag_id, p_post)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req) {
+                    onSuccess: function (req) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
@@ -2181,7 +2222,7 @@ function save_tag()
                     method: 'get',
                     parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         remove_waiting_box();
                         removeDiv('tag_div');
                     }
@@ -2210,7 +2251,7 @@ function action_tag_select(p_dossier, ag_id)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
@@ -2220,9 +2261,9 @@ function action_tag_select(p_dossier, ag_id)
                         }
                         var code_html = getNodeText(html[0]);
                         code_html = unescape_xml(code_html);
-                        add_div({id: 'tag_div', style: '', cssclass: 'inner_box', drag: 1});
-                        $('tag_div').style.top = (posY - 70)+"px";
-                        $('tag_div').style.left = (posX - 70)+"px";
+                        pos = fixed_position(35, 229);
+                        add_div({id: 'tag_div', style: pos, cssclass: 'inner_box tag', drag: 1});
+
                         remove_waiting_box();
                         $('tag_div').innerHTML = code_html;
                     }
@@ -2248,7 +2289,7 @@ function action_tag_add(p_dossier, ag_id, t_id)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
@@ -2286,7 +2327,7 @@ function action_tag_remove(p_dossier, ag_id, t_id)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
@@ -2324,7 +2365,7 @@ function search_display_tag(p_dossier, p_prefix)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('code');
                         if (html.length === 0)
@@ -2336,8 +2377,8 @@ function search_display_tag(p_dossier, p_prefix)
                         code_html = unescape_xml(code_html);
                         remove_waiting_box();
                         add_div({id: p_prefix + 'tag_div', style: '', cssclass: 'inner_box', drag: 1});
-                        $(p_prefix + 'tag_div').style.top = posY - 80+"px";
-                        $(p_prefix + 'tag_div').style.left = posX - 200+"px";
+                        $(p_prefix + 'tag_div').style.top = posY - 80 + "px";
+                        $(p_prefix + 'tag_div').style.left = posX - 200 + "px";
                         remove_waiting_box();
                         $(p_prefix + 'tag_div').innerHTML = code_html;
 
@@ -2369,7 +2410,7 @@ function search_add_tag(p_dossier, p_tag_id, p_prefix)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('html');
                         if (html.length === 0)
@@ -2406,7 +2447,7 @@ function search_clear_tag(p_dossier, p_prefix)
                 {
                     method: 'get', parameters: queryString,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('html');
                         if (html.length === 0)
@@ -2432,6 +2473,13 @@ function action_show_checkbox()
         a[i].style.display = 'block';
     }
 }
+function action_hide_checkbox()
+{
+    var a = document.getElementsByName('ag_id_td');
+    for (var i = 0; i < a.length; i++) {
+        a[i].style.display = 'none';
+    }
+}
 /**
  * 
  * @param {type} obj
@@ -2453,7 +2501,7 @@ function calendar_zoom(obj)
                 {
                     method: 'get', parameters: query,
                     onFailure: ajax_misc_failure,
-                    onSuccess: function(req, j) {
+                    onSuccess: function (req, j) {
                         var answer = req.responseXML;
                         var html = answer.getElementsByTagName('html');
                         if (html.length === 0)
@@ -2528,7 +2576,80 @@ function stock_add_row()
 }
 function show_description(p_id)
 {
-    $('print_desc'+p_id).hide();
-    $('input_desc'+p_id).show();
-    
+    $('print_desc' + p_id).hide();
+    $('input_desc' + p_id).show();
+
+}
+/**
+ * Hightlight the row we select and restore previous one
+ * @param {type} x
+ * @returns {undefined}
+ */
+var old_class = null;
+var old_select = null;
+
+function select_cat(x)
+{
+    if (old_select != null)
+    {
+        $(old_select).className = old_class;
+    }
+    old_select = $('select_cat_row_' + x);
+    old_class = old_select.className;
+    $(old_select).className = "highlight";
+    $('fd_id').value = x;
+}
+/**
+ * Show the DIV and hide the other, the array of possible DIV are
+ * in a_tabs, 
+ * @param {array} a_tabs name of possible tabs
+ * @param {strng} p_display_tab tab to display
+ */
+function show_tabs(a_tabs, p_display_tab)
+{
+    try
+    {
+        if (a_tabs.length == 0)
+            trow('a_tabs in empty');
+        var i = 0;
+        for (i = 0; i < a_tabs.length; i++) {
+            $(a_tabs[i]).hide();
+        }
+        $(p_display_tab).show();
+    } catch (e) {
+        alert(e.message);
+    }
+
+}
+/**
+ * Change the class of all the "LI" element of a UL or OL
+ * @param node of ul (this)
+ */
+function unselect_other_tab(p_tab)
+{
+    try {
+        var other = p_tab.getElementsByTagName("li");
+        var i = 0;
+        var tab = null;
+        for (i = 0; i < other.length; i++) {
+            tab = other[i];
+            tab.className = "tabs";
+        }
+    } catch (e) {
+        if (console)
+            console.log(e.message);
+    }
+}
+/**
+ * logout function call from ajax
+ * @see ajax_disconnected
+ * @returns {undefined}
+ */
+function logout()
+{
+    var tmp_place = window.location.href
+    var tmp_b = tmp_place.split('/')
+    var tmp_last = tmp_b.length - 1
+    var place_logout = tmp_place.replace(tmp_b[tmp_last], 'logout.php');
+    window.location.href = place_logout;
 }
\ No newline at end of file
