@@ -74,7 +74,9 @@ if ( $version < DBVERSIONREPO )
 {
     echo '<h2 class="error" style="font-size:12px">'._("Votre base de données n'est pas à jour").'   ';
     $a=_("cliquez ici pour appliquer le patch");
-    $base=dirname($_SERVER['REQUEST_URI']).'/admin/setup.php';
+    $base = dirname($_SERVER['REQUEST_URI']);
+    if ($base == '/') { $base = ''; }
+    $base .= '/admin/setup.php';
     echo '<a hreF="'.$base.'">'.$a.'</a></h2>';
 
 }
@@ -157,7 +159,7 @@ echo '<div id="module">'.$result.'</div>';
 echo '</div>';
 ?>
 <div class="foldercontent">
-<?php echo '<h2 >'._('Choississez un dossier').'</h2>';?>
+<?php echo '<h2 >'._('Choisissez un dossier').'</h2>';?>
 	<span style="display:block;margin:2.5%">
  <?php
                         echo _('Filtre').HtmlInput::infobulle(23);
