@@ -290,26 +290,35 @@ function html_page_start($p_theme="", $p_script="", $p_script2="")
 		else
 			$title=$_REQUEST['ac']."  ".$title;
 	}
-    echo '<!doctype html>';
+    $is_msie=is_msie();
+    
+    if ($is_msie == 0 ) 
+        echo '<!doctype html>';
+    else
+         echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 3.2 FINAL//EN" >';
+    
     echo "<HTML>";
 
     if ($p_script2 != "")
 	$p_script2 = '<script src="' . $p_script2 . '" type="text/javascript"></script>';
-
-    echo "<HEAD>
+    $style=trim($style);
+    $DIR=dirname(__FILE__);
+    echo "<HEAD>";
+    if ( $is_msie == 1 )echo '      <meta http-equiv="x-ua-compatible" content="IE=edge"/>';
+    echo "
     <TITLE>$title</TITLE>
 	<link rel=\"icon\" type=\"image/ico\" href=\"favicon.ico\" />
     <META http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\">
-    <LINK REL=\"stylesheet\" type=\"text/css\" href=\"$style\" media=\"screen\">
+    <LINK REL=\"stylesheet\" type=\"text/css\" href=\"./$style\" media=\"screen\">
     <link rel=\"stylesheet\" type=\"text/css\" href=\"style-print.css\" media=\"print\">" .
     $p_script2 . "
     ";
     echo '<script language="javascript" src="js/calendar.js"></script>
     <script type="text/javascript" src="js/lang/calendar-en.js"></script>
     <script language="javascript" src="js/calendar-setup.js"></script>
-    <LINK REL="stylesheet" type="text/css" href="calendar-blue.css" media="screen">
-    </HEAD>
-    ';
+    <LINK REL="stylesheet" type="text/css" href="calendar-blue.css" media="screen">';
+
+    echo '    </HEAD>    ';
 
     echo "<BODY $p_script>";
     echo '<div id="info_div"></div>';
@@ -632,7 +641,7 @@ function sql_filter_per($p_cn, $p_from, $p_to, $p_form='p_id', $p_field='jr_tech
 
 function alert($p_msg, $buffer=false)
 {
-    $r = '<script language="javascript">';
+    $r = '<script>';
     $r.= 'alert(\'' . j($p_msg) . '\')';
     $r.= '</script>';
 
@@ -783,8 +792,8 @@ function ajax_disconnected($div)
 	$html.=h2(_('Données non disponibles'), 'class="title" style="width:auto"');
 	$html.=h2(_('Veuillez vous reconnecter'), 'class="error"');
 	$html.=alert(_("Déconnecté"), true);
+        $html.="<script>logout();</script>";
 	$html = escape_xml($html);
-
 	header('Content-type: text/xml; charset=UTF-8');
 	echo <<<EOF
 <?xml version="1.0" encoding="UTF-8"?>
@@ -983,7 +992,15 @@ function show_menu($module, $idx)
 				$array=compute_variable($file[0]['me_parameter']);
 				put_global($array);
 			}
-
+                        /*
+                         * Log the file we input to put in the folder test-noalyss for replaying it
+                         */
+                        if (LOGINPUT) {
+                                $file_loginput=fopen($_ENV['TMP'].'/scenario-'.$_SERVER['REQUEST_TIME'].'.php','a+');
+                                fwrite($file_loginput, "include '".$file[0]['me_file']."';");
+                                fwrite($file_loginput,"\n");
+                                fclose($file_loginput);
+                        }
 			// if file is not a plugin, include the file, otherwise
 			// include the plugin launcher
 			if ( $file[0]['me_type'] != 'PL')
@@ -1108,4 +1125,55 @@ function get_array_column($p_array,$key)
     }
     return $array;
 }
+
+/**
+ * This function create a ledger object and return the right one.
+ * It uses the factory pattern
+ * @param Database $p_cn
+ * @param type $ledger_id 
+ * @return Acc_Ledger
+ * @throws Exception
+ */
+function factory_Ledger(Database &$p_cn, $ledger_id)
+{
+    include_once 'class_acc_ledger_sold.php';
+    include_once 'class_acc_ledger_purchase.php';
+    include_once 'class_acc_ledger_fin.php';
+    
+    $ledger=new Acc_Ledger($p_cn, $ledger_id);
+    $type=$ledger->get_type();
+
+    switch ($type)
+    {
+        case 'VEN':
+            $obj=new Acc_Ledger_Sold($p_cn, $ledger_id);
+            break;
+        case 'ACH':
+            $obj=new Acc_Ledger_Purchase($p_cn, $ledger_id);
+            break;
+        case 'FIN':
+            $obj= new Acc_Ledger_Fin($p_cn, $ledger_id);
+            break;
+        case 'ODS':
+            $obj=$ledger;
+            break;
+
+        default:
+            throw new Exception('Ledger type not found');
+    }
+    return $obj;
+}
+/**
+ * Check if we use IE 8 or 9
+ * @return int 1 for IE8-9;0 otherwise
+ */
+function is_msie()
+{
+    if ( strpos ($_SERVER['HTTP_USER_AGENT'],'MSIE 8.0')  != 0 ||
+         strpos ($_SERVER['HTTP_USER_AGENT'],'MSIE 9.0')  != 0 )
+       $is_msie=1;
+    else
+        $is_msie=0;
+    return $is_msie;
+}
 ?>
