@@ -151,7 +151,7 @@ class Acc_Account_Ledger
                                  "j_debit, jr_internal,jr_pj_number,
 								 coalesce(comptaproc.get_letter_jnt(j_id),-1) as letter ".
                                  ",pcm_lib ".
-				 ",jr_tech_per,p_exercice,jrn_def_name".
+				 ",jr_tech_per,p_exercice,jrn_def_name,jrn_def_code".
                                  " from jrnx left join jrn_def on (jrn_def_id=j_jrn_def )".
                                  " left join jrn on (jr_grpt_id=j_grpt)".
                                  " left join tmp_pcmn on (j_poste=pcm_val)".
@@ -283,7 +283,7 @@ class Acc_Account_Ledger
 
         return array('debit'=>$r['sum_deb'],
                      'credit'=>$r['sum_cred'],
-                     'solde'=>abs($r['sum_deb']-$r['sum_cred']));
+                     'solde'=>abs(bcsub($r['sum_deb'],$r['sum_cred'])));
     }
     /*!
      * \brief isTva tell is a poste is used for VAT
@@ -373,7 +373,7 @@ class Acc_Account_Ledger
 		    $progress=bcsub($sum_deb,$sum_cred);
 			$side="&nbsp;".$this->get_amount_side($progress);
 		    echo "<TR style=\"font-weight:bold\">".
-		      "<TD></TD>".
+		      "<TD>$old_exercice</TD>".
 		      td('').
 		      "<TD></TD>".
 		      "<TD>Totaux</TD>".
@@ -464,7 +464,6 @@ class Acc_Account_Ledger
 	  break;
 	default:
 	  throw new Exception(" Fonction HtmlTableHeader argument actiontarget invalid");
-	  exit;
 	}
         $hid=new IHidden();
 
@@ -637,7 +636,8 @@ class Acc_Account_Ledger
         return $sql;
     }
 	/**
-	 * Find the card which is using the current account
+	 * Find the id of the cards which are using the current account
+         * 
 	 * @return an array of f_id
 	 */
 	function find_card()
@@ -651,6 +651,7 @@ class Acc_Account_Ledger
         $cn=new Database(dossier::id());
         $a=new Acc_Account_Ledger($cn,550);
         echo ' Journal 4 '.$a->belong_ledger(4);
+        return $a->belong_ledger(4);;
 
     }
 }
