@@ -45,15 +45,25 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		$this->type = 'FIN';
 	}
 
-	/**\brief verify that the data are correct before inserting or confirming
-	 * \param an array (usually $_POST)
-	 * \return String
-	 * \throw Exception on error occurs
+	/**
+         * Verify that the data are correct before inserting or confirming
+         * @brief verify the data 
+	 * @param an array (usually $_POST)
+	 * @return String
+	 * @throw Exception on error occurs
 	 */
 
 	public function verify($p_array)
 	{
 		global $g_user;
+                if (is_array($p_array ) == false || empty($p_array))
+                    throw new Exception ("Array empty");
+               /*
+                * Check needed value
+                */
+                check_parameter($p_array,'p_jrn');
+
+                
 		extract($p_array);
 		/* check for a double reload */
 		if (isset($mt) && $this->db->count_sql('select jr_mt from jrn where jr_mt=$1', array($mt)) != 0)
@@ -282,8 +292,8 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			{
 				if ($e->getCode() == 1)
 				{
-					echo "Aucune période ouverte";
-					exit();
+					throw  Exception(_("Aucune période ouverte"));
+					
 				}
 			}
 			$label = HtmlInput::infobulle(3);
@@ -302,7 +312,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		$add_js = 'onchange="'.$onchange.'"';
 		$wLedger = $this->select_ledger('FIN', 2);
 		if ($wLedger == null)
-			exit('Pas de journal disponible');
+			throw  Exception(_('Pas de journal disponible'));
 
 		$wLedger->javascript = $add_js;
 
@@ -374,6 +384,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			$W1->value = $tiers;
 			$W1->extra = 'deb';  // credits
 			$W1->typecard = 'deb';
+                        $W1->style=' style = "vertical-align:65%"';
 			$W1->set_dblclick("fill_ipopcard(this);");
 			$W1->set_attribute('ipopup', 'ipopcard');
 
@@ -420,6 +431,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			${"e_concerned" . $i} = (isset(${"e_concerned" . $i})) ? ${"e_concerned" . $i} : ""
 			;
 			$wConcerned = new IConcerned("e_concerned" . $i, ${"e_concerned" . $i});
+                        $wConcerned->tiers="e_other" . $i;
 			$wConcerned->setReadOnly($pview_only);
 			$wConcerned->amount_id = "e_other" . $i . "_amount";
 
@@ -728,7 +740,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 			$this->db->start();
 			$amount = 0.0;
 			$idx_operation = 0;
-			$ret = '<table class="result" style="width:75%">';
+			$ret = '<table class="result" >';
 			$ret.=tr(th('Date').th('n° interne') . th('Quick Code') . th('Nom') . th('Libellé') . th('Montant', ' style="text-align:right"'));
 			// Credit = goods
 			$get_solde=true;
@@ -877,7 +889,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 						{
 							// Add a "concerned operation to bound these op.together
 							//
-                            $rec = new Acc_Reconciliation($this->db);
+                                                        $rec = new Acc_Reconciliation($this->db);
 							$rec->set_jr_id($jr_id);
 
 							if (isNumber($rRapt) == 1)
@@ -909,7 +921,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 					$op->oa_group = $this->db->get_next_seq("s_oa_group"); /* for analytic */
 					$op->j_id = $j_id;
 					$op->oa_date = $e_date;
-					$op->oa_debit = ($amount < 0 ) ? 't' : 'f';
+					$op->oa_debit = 'f';
 					$op->oa_description = sql_string($comment);
 					$op->save_form_plan($_POST, $i, $j_id);
 				}
@@ -920,8 +932,8 @@ class Acc_Ledger_Fin extends Acc_Ledger
 				$js_detail = HtmlInput::detail_op($jr_id, $internal);
 				// Compute display
 				$row = td($e_date).td($js_detail) . td(${"e_other$i"}) . td($fPoste->strAttribut(ATTR_DEF_NAME)) . td(${"e_other" . $i . "_comment"}) . td(nbm(${"e_other$i" . "_amount"}), 'class="num"');
-
-				$ret.=tr($row);
+                                $class=($i%2==0)?' class="even" ':' class="odd" ';
+				$ret.=tr($row,$class);
 
 
 				if ($i == 0)
@@ -949,12 +961,12 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		}
 		catch (Exception $e)
 		{
-			echo '<span class="error">' .
+			$r = '<span class="error">' .
 			'Erreur dans l\'enregistrement ' .
 			__FILE__ . ':' . __LINE__ . ' ' .
 			$e->getMessage();
 			$this->db->rollback();
-			exit();
+			throw  Exception($r);
 		}
 		$this->db->commit();
 		$r = "";
@@ -999,7 +1011,7 @@ class Acc_Ledger_Fin extends Acc_Ledger
 		$wLedger = $this->select_ledger('fin', 3);
 
 		if ($wLedger == null)
-			exit(_('Pas de journal disponible'));
+			throw  Exception(_('Pas de journal disponible'));
 
 		if (count($wLedger->value) > 1)
 		{
