@@ -61,6 +61,14 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
     public function verify($p_array)
     {
         global $g_parameter,$g_user;
+        
+        if (is_array($p_array ) == false || empty($p_array))
+                    throw new Exception ("Array empty");
+        /*
+         * Check needed value
+         */
+        check_parameter($p_array,'p_jrn,e_date,e_client');
+
         extract ($p_array);
         /* check if we can write into this ledger */
         if ( $g_user->check_jrn($p_jrn) != 'W' )
@@ -266,20 +274,19 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
      * @param Fiche $p_fiche Concerned Card (purchase items)
      * @param type $p_tva_bot 0 TVA on one side, 1 TVA on both side
      */
-    private function compute_no_deductible(Acc_Compute $p_nd_amount, Fiche $p_fiche, $p_tva_both)
+    private function compute_no_deductible(Acc_Compute $p_nd_amount, Fiche $p_fiche)
     {
-
         if (!$p_fiche->empty_attribute(ATTR_DEF_DEPENSE_NON_DEDUCTIBLE))
         {
             $p_nd_amount->amount_nd_rate = $p_fiche->strAttribut(ATTR_DEF_DEPENSE_NON_DEDUCTIBLE);
             $p_nd_amount->compute_nd();
         }
-        if (!$p_fiche->empty_attribute(ATTR_DEF_TVA_NON_DEDUCTIBLE) && $tva_both == 0)
+        if (!$p_fiche->empty_attribute(ATTR_DEF_TVA_NON_DEDUCTIBLE) )
         {
             $p_nd_amount->nd_vat_rate = $p_fiche->strAttribut(ATTR_DEF_TVA_NON_DEDUCTIBLE);
             $p_nd_amount->compute_nd_vat();
         }
-        if (!$p_fiche->empty_attribute(ATTR_DEF_TVA_NON_DEDUCTIBLE_RECUP) && $p_tva_both == 0)
+        if (!$p_fiche->empty_attribute(ATTR_DEF_TVA_NON_DEDUCTIBLE_RECUP) )
         {
             $p_nd_amount->nd_ded_vat_rate = $p_fiche->strAttribut(ATTR_DEF_TVA_NON_DEDUCTIBLE_RECUP);
             $p_nd_amount->compute_ndded_vat();
@@ -392,7 +399,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $op->j_id=$j_id;
                 $op->oa_date=$p_acc_operation->date;
 
-                $op->oa_debit=($p_nd_amount->nd_vat > 0 )?'t':'f';
+                $op->oa_debit='t';
                 $op->oa_description=sql_string('ND_TVA');
                 $op->oa_jrnx_id_source=$source_j_id;
                 $op->save_form_plan_vat_nd($_POST,$idx,$j_id,$p_nd_amount->nd_vat,$p_acc_operation->jrnx_id);
@@ -431,7 +438,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $op->j_id=$j_id;
                 $op->oa_date=$p_acc_operation->date;
 
-                $op->oa_debit=($p_nd_amount->nd_ded_vat > 0 )?'t':'f';
+                $op->oa_debit='t';
                 $op->oa_description=sql_string('DED_TVA ');
                 $op->oa_jrnx_id_source=$source_j_id;
                 $op->save_form_plan_vat_nd($_POST,$idx,$j_id,$p_nd_amount->nd_ded_vat);
@@ -520,6 +527,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $tot_perso=0;
             $tot_tva_nd=0;
             $tot_tva_ndded=0;
+            $tot_tva_reversed=0;
 			$tva=array();
             /* Save all the items without vat and no deductible vat and expense*/
             for ($i=0;$i< $nb_item;$i++)
@@ -530,7 +538,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 /* First we save all the items without vat */
                 $fiche=new Fiche($this->db);
                 $fiche->get_by_qcode(${"e_march".$i});
-				$tva_both=0;
+		$tva_both=0;
                 /* tva */
                 if ($g_parameter->MY_TVA_USE=='Y')
                 {
@@ -538,7 +546,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                     $oTva=new Acc_Tva($this->db);
                     $oTva->set_parameter('id',$idx_tva);
                     $oTva->load();
-					$tva_both=$oTva->get_parameter("both_side");
+                    $tva_both=$oTva->get_parameter("both_side");
                 }
                 /* -- Create acc_operation -- */
                 $acc_operation=new Acc_Operation($this->db);
@@ -557,11 +565,11 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $acc_amount->check=false;
                 $acc_amount->set_parameter('amount',$amount);
                 
-                
+                // Compute VAT or take the given one
                 if ( $g_parameter->MY_TVA_USE=='Y')
                 {
                     $acc_amount->set_parameter('amount_vat_rate',$oTva->get_parameter('rate'));
-                    if ( strlen(trim(${'e_march'.$i.'_tva_amount'})) ==0)
+                    if ( strlen(trim(${'e_march'.$i.'_tva_amount'})) ==0 || ${'e_march'.$i.'_tva_amount'} == 0)
                     {
                         $acc_amount->compute_vat();
 
@@ -571,14 +579,17 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                         $acc_amount->amount_vat= ${'e_march'.$i.'_tva_amount'};
 
                     }
-                    if ($tva_both==0) $tot_tva=bcadd($tot_tva,$acc_amount->amount_vat);
+                   $tot_tva=bcadd($tot_tva,$acc_amount->amount_vat);
                 }
 
                
                 /* compute ND */
-                $this->compute_no_deductible($acc_amount, $fiche, $tva_both);
+                $save_amount_vat=$acc_amount->amount_vat;
+                $this->compute_no_deductible($acc_amount, $fiche);
                 $acc_amount->correct();
-
+                // TVA which avoid 
+                $acc_amount->amount_unpaid=($tva_both == 1 ) ? $save_amount_vat :0 ;
+                $tot_tva_reversed=bcadd($tot_tva_reversed,$acc_amount->amount_unpaid);
                 
 
               
@@ -650,7 +661,6 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 //-----
                 if ( $g_parameter->MY_TVA_USE=='Y')
                 {
-                    if ( $tva_both==1) $n_both=$acc_amount->amount_vat;
 
                     $r=$this->db->exec_sql("select insert_quant_purchase ".
                                            "(null".
@@ -664,7 +674,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                                            ",".$acc_amount->nd_vat.	     /* 9 */
                                            ",".$acc_amount->nd_ded_vat.    /* 10 */
                                            ",".$acc_amount->amount_perso.  /* 11 */ 
-                                           ",'".$e_client."',".$n_both.")");	     /* 12 */
+                                           ",'".$e_client."',". $acc_amount->amount_unpaid.")");	     /* 12 */
 
                 }
                 else
@@ -681,7 +691,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                                            ",0".
                                            ",".$acc_amount->nd_ded_vat.
                                            ",".$acc_amount->amount_perso.
-                                           ",'".$e_client."',".$n_both.")");
+                                           ",'".$e_client."',".$acc_amount->amount_unpaid.")");
 
 
                 }
@@ -692,7 +702,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $acc_operation=new Acc_Operation($this->db);
             $acc_operation->date=$e_date;
             $acc_operation->poste=$poste;
-            $acc_operation->amount=$cust_amount;
+            $acc_operation->amount=$cust_amount-$tot_tva_reversed;
             $acc_operation->grpt=$seq;
             $acc_operation->jrn=$p_jrn;
             $acc_operation->type='c';
@@ -732,16 +742,17 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                     {
                         $poste_vat=$oTva->get_side('c');
                         $cust_amount=bcadd($tot_amount,$tot_tva);
+                        $cust_amount=bcsub($tot_amount,$tot_tva_reversed);
                         $acc_operation=new Acc_Operation($this->db);
                         $acc_operation->date=$e_date;
                         $acc_operation->poste=$poste_vat;
-                        $acc_operation->amount=$value;
+                        $acc_operation->amount=$tot_tva_reversed;
                         $acc_operation->grpt=$seq;
                         $acc_operation->jrn=$p_jrn;
                         $acc_operation->type='c';
                         $acc_operation->periode=$tperiode;
                         $acc_operation->insert_jrnx();
-						 if ( $value < 0 ) $tot_debit=bcadd($tot_debit,abs($value));
+			if ( $value < 0 ) $tot_debit=bcadd($tot_debit,abs($value));
                     }
 
                 }
@@ -900,7 +911,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $e->getMessage().$e->getTraceAsString();
 
             $this->db->rollback();
-            exit();
+            throw  new Exception($e);
         }
         $this->db->commit();
         return $internal;
@@ -1006,8 +1017,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             {
                 if ($e->getCode() == 1 )
                 {
-                    echo _("Aucune période ouverte");
-                    exit();
+                    throw  Exception( _("Aucune période ouverte"));
                 }
             }
 
@@ -1032,7 +1042,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
 		$add_js.='update_row("sold_item");';
 
 		$wLedger=$this->select_ledger('ACH',2);
-        if ($wLedger == null) exit (_('Pas de journal disponible'));
+        if ($wLedger == null) throw  Exception(_('Pas de journal disponible'));
         $wLedger->javascript="onChange='update_predef(\"ach\",\"f\",\"".$_REQUEST['ac']."\");$add_js'";
         $wLedger->table=1;
         $f_jrn=$wLedger->input();
@@ -1386,7 +1396,6 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $r.='<th style="text-align:right">' . _('Montant TVAC') . '</th>';
         } else {
             $r.='<th style="text-align:right">' . _('Montant') . '</th>';
-            $r.="<th style=\"text-align:right\">"._('quantité')."</th>";
         }
 
         /* if we use the AC */
@@ -1421,23 +1430,19 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             else
                 $fiche_name=$fiche->strAttribut (ATTR_DEF_NAME);
 
+            $amount=bcmul(${"e_march".$i."_price"},${'e_quant'.$i});
             if ( $g_parameter->MY_TVA_USE=='Y')
             {
                 $idx_tva=${"e_march".$i."_tva_id"};
                 $oTva=new Acc_Tva($this->db);
                 $oTva->set_parameter('id',$idx_tva);
                 $oTva->load();
-            }
-            $amount=bcmul(${"e_march".$i."_price"},${'e_quant'.$i});
+                $op=new Acc_Compute();
 
-            if ( $g_parameter->MY_TVA_USE=='Y')
-            {
-				$op=new Acc_Compute();
-
-				$op->set_parameter("amount",$amount);
-				$op->set_parameter('amount_vat_rate',$oTva->get_parameter('rate'));
-				$op->compute_vat();
-				 $tva_computed=$op->get_parameter('amount_vat');
+                $op->set_parameter("amount",$amount);
+                $op->set_parameter('amount_vat_rate',$oTva->get_parameter('rate'));
+                $op->compute_vat();
+                $tva_computed=$op->get_parameter('amount_vat');
                 //----- if tva_amount is not given we compute the vat ----
                 if ( strlen (trim (${'e_march'.$i.'_tva_amount'})) == 0)
                 {
@@ -1450,8 +1455,9 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                     $tva[$idx_tva]+=$tva_item;
                 else
                     $tva[$idx_tva]=$tva_item;
-                $tot_tva=round(bcadd($tva_item,$tot_tva),2);
-				$tot_row=bcadd($tot_row,$tva_item);
+               
+		
+                
             }
             $tot_amount=round(bcadd($tot_amount,$amount),2);
 			$tot_row=bcadd($tot_row,$amount);
@@ -1468,32 +1474,39 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $r.='<td class="num">';
             $r.=nbm(${"e_quant".$i});
             $r.='</td>';
+            $both_side=0;
             if ($g_parameter->MY_TVA_USE == 'Y')
             {
                 $r.='<td class="num">';
                 $r.=$oTva->get_parameter('label');
+                $both_side=$oTva->get_parameter("both_side");
+                if ( $both_side == 0) {
+                    $tot_row=bcadd($tot_row,$tva_item);
+                    $tot_tva=round(bcadd($tva_item,$tot_tva),2);
+                }
                 $r.='</td>';
                 /* warning if tva_computed and given are not the
                    same */
-				bcscale(2);
-                if ( bcsub($tva_item,$tva_computed) != 0)
+		bcscale(2);
+                $css_void_tva=($both_side == 1)?'style="text-decoration:line-through"':'';
+                if ( bcsub($tva_item,$tva_computed) != 0 && ! ($tva_item == 0 && $both_side == 1))
                 {
 
-					 $r.='<td style="background-color:red" class="num">';
+					 $r.='<td style="background-color:red" class="num" '.$css_void_tva.'>';
 					 $r.=HtmlInput::infobulle(28);
-                    $r.='<a href="#" class="error" style="display:inline" title="'. _("Attention Différence entre TVA calculée et donnée").'">'
+                                         $r.='<a href="#" class="error" style="display:inline" title="'. _("Attention Différence entre TVA calculée et donnée").'">'
 							.nbm($tva_item).'<a>';
                 }
-				else{
-					 $r.='<td  class="num">';
-					$r.=nbm($tva_item);
-				}
+                else{
+                        $r.='<td  class="num" '.$css_void_tva.'>';
+                        $r.=nbm($tva_item);
+                }
+                $r.='</td>';
+                $r.='<td class="num">';
+                $r.=nbm(round($amount,2));
                 $r.='</td>';
-				$r.='<td class="num">';
-				$r.=nbm(round($amount,2));
-				$r.='</td>';
             }
-			$r.='<td class="num">';
+            $r.='<td class="num">';
             $r.=nbm(round($tot_row,2));
             $r.='</td>';
             // encode the pa
@@ -1515,20 +1528,42 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $r.='</tr>';
 
         }
-
+        // Add the sum
+        $decalage=($g_parameter->MY_TVA_USE == 'Y')?'<td></td><td></td><td></td><td></td>':'<td></td>';
+         $tot = round(bcadd($tot_amount, $tot_tva), 2);
+        $tot_tva=nbm($tot_tva);
+        $tot=nbm($tot);
+        $str_tot=_('Totaux');
+        $tot_amount=nbm($tot_amount);
+        $r.=<<<EOF
+<tr class="highlight">
+    {$decalage}            
+     <td>
+                {$str_tot}
+     </td>
+    <td class="num">
+        {$tot_tva}
+    </td>
+    <td class="num">
+        {$tot_amount}
+    </td>
+    <td class="num">
+        {$tot}
+    </td>
+EOF;
 
         $r.='</table>';
         $r.='</p>';
         if ( $g_parameter->MY_ANALYTIC!='nu' && !$p_summary) // use of AA
             $r.='<input type="button" class="button" value="'._('Vérifiez imputation analytique').'" onClick="verify_ca(\'\');">';
+        
+        $r.=(! $p_summary )?'<div id="total_div_id" >':'<div>';
         $r.='<h2>Totaux</h2>';
-        $r.='<p class="decale">';
-        $tot = round(bcadd($tot_amount, $tot_tva), 2);
         /* use VAT */
         if ($g_parameter->MY_TVA_USE == 'Y') {
             $r.='<table>';
             $r.='<tr><td>Total HTVA</td>';
-            $r.=td(hb(nbm($tot_amount) ),'class="num"');
+            $r.=td(hb($tot_amount ),'class="num"');
             foreach ($tva as $i => $value) {
                 $oTva->set_parameter('id', $i);
                 $oTva->load();
@@ -1536,13 +1571,13 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
                 $r.='<tr><td>  TVA ' . $oTva->get_parameter('label').'</td>';
                 $r.=td(hb(nbm($tva[$i])),'class="num"');
             }
-            $r.='<tr>'.td(_('Total TVA')).td(hb(nbm($tot_tva)),'class="num"');
-            $r.='<tr>'.td(_('Total TVAC')).td(hb(nbm($tot)),'class="num"');
+            $r.='<tr>'.td(_('Total TVA')).td(hb($tot_tva),'class="num"');
+            $r.='<tr>'.td(_('Total TVAC')).td(hb($tot),'class="num"');
             $r.='</table>';
         } else {
-            $r.='<br>Total '.hb(nbm($tot));
+            $r.='<br>Total '.hb($tot);
         }
-        $r.='</p>';
+        $r.='</div>';
         /*  Add hidden */
         $r.=HtmlInput::hidden('e_client',$e_client);
         $r.=HtmlInput::hidden('nb_item',$nb_item);
@@ -1577,20 +1612,11 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
             $r.=HtmlInput::hidden("e_quant".$i,${"e_quant".$i});
 
         }
-	if ( ! $p_summary )
-            $r.=$this->extra_info();
-	// Show the available repository
-        if ($g_parameter->MY_STOCK == 'Y') {
-            $sel = HtmlInput::select_stock($this->db, 'repo', 'W');
-            $sel->readOnly = $p_summary;
-            if ($p_summary == true)
-                $sel->selected = $repo;
-            $r.='<h2>Dépôt</h2>';
-            $r.="<p class=\"decale\"> Dans le dépôt : ";
-            $r.=$sel->input();
-            $r.='</p>';
-        }
-	if ( $e_mp!=0 && strlen (trim (${'e_mp_qcode_'.$e_mp})) != 0 )
+
+        /**
+         * 
+         */
+        if ( $e_mp!=0 && strlen (trim (${'e_mp_qcode_'.$e_mp})) != 0 )
         {
             $r.=HtmlInput::hidden('e_mp_qcode_'.$e_mp,${'e_mp_qcode_'.$e_mp});
             $r.=HtmlInput::hidden('acompte',$acompte);
@@ -1599,13 +1625,8 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
            $r.=HtmlInput::hidden('qcode_benef', ${'e_mp_qcode_' . $e_mp});
 			$fname = new Fiche($this->db);
 			$fname->get_by_qcode(${'e_mp_qcode_' . $e_mp});
-			/*$r.="<div style=\"clear:both\"></div>";
-			$r.='<div style="float:left"><h2 class="info">' . "Payé par " . ${'e_mp_qcode_' . $e_mp} .
-					" ".$fname->getName() ."</h2> ".
-					'<p>'._('Déduction acompte ').h($acompte).'</p>'.
-					_('Libellé :' ).h($e_comm_paiement).'</div>';*/
-            $r.='<h2>' . "Payé par " . ${'e_mp_qcode_' . $e_mp} .
-                    " " . $fname->getName() . '</H2> ' . '<p class="decale">' . _('Déduction acompte ') . h($acompte) . '</p>' .
+            $r.='<h2>' . _("Payé par")." " . ${'e_mp_qcode_' . $e_mp} .
+                    " " . $fname->getName() . '</h2> ' . '<p class="decale">' . _('Déduction acompte ') . h($acompte) . '</p>' .
                     _('Libellé :') . h($e_comm_paiement) ;
             $r.='<br>';
             $r.='<br>';
@@ -1624,7 +1645,7 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
     public function extra_info()
     {
         $r="";
-        $r.='<h2> Facturation</h2>';
+        $r = '<div id="facturation_div_id" style="height:185px;height:10rem">';
         $r.='<p class="decale">';
         // check for upload piece
         $file=new IFile();
@@ -1649,13 +1670,17 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $r.=_('Numero de bon de commande : ').$obj->input('bon_comm').'<br>';
         $r.=_('Autre information : ').$obj->input('other_info').'<br>';
         $r.='</p>';
+        $r.='</div>';
         return $r;
     }
 
 
-    /*!\brief update the payment
+    /**
+     * @brief update the payment
+     * @todo to remove, obsolete
+     * @deprecated
      */
-    function show_unpaid()
+    function show_unpaid_deprecated()
     {
         // Show list of unpaid sell
         // Date - date of payment - Customer - amount
@@ -1666,9 +1691,9 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
 
 
         $sql=SQL_LIST_UNPAID_INVOICE_DATE_LIMIT." and jr_def_id=".$this->id ;
-        list($max_line,$list)=ListJrn($this->db,$sql,null,$offset,1);
+        list($max_line,$list)=$this->list_operation($sql,null,$offset,1);
         $sql=SQL_LIST_UNPAID_INVOICE." and jr_def_id=".$this->id ;
-        list($max_line2,$list2)=ListJrn($this->db,$sql,null,$offset,1);
+        list($max_line2,$list2)=$this->list_operation($sql,null,$offset,1);
 
         // Get the max line
         $m=($max_line2>$max_line)?$max_line2:$max_line;
@@ -1717,6 +1742,47 @@ class  Acc_Ledger_Purchase extends Acc_Ledger
         $ret = $this->db->exec_sql($sql, array($this->id,$p_from, $p_end));
         return $ret;
     }
+    /**
+     * @brief compute an array with the heading cells for the
+     * details, used for the export in CSV
+     * @return array
+     */
+    static function heading_detail_purchase()
+    {
+        $array['jr_id'] = _('Numéro opération');
+        $array['jr_date'] = _('Date');
+        $array['jr_date_paid'] = _('Date paiement');
+        $array['jr_ech'] = _('Date échéance');
+        $array['jr_tech_per'] = _('Période');
+        $array['jr_comment'] = _('Libellé');
+        $array['jr_pj_number'] = _('Pièce');
+        $array['jr_internal'] = _('Interne');
+        $array['jr_def_id'] = _('Code journal');
+        $array['j_poste'] = _('Poste');
+        $array['j_text'] = _('Commentaire');
+        $array['j_qcode'] = _('Code Item');
+        $array['item_card'] = _('N° fiche');
+        $array['item_name'] = _('Nom fiche');
+        $array['qp_supplier'] = _('N° fiche fournisseur');
+        $array['tiers_name'] = _('Nom fournisseur');
+        $array['quick_code'] = _('Code fournisseur');
+        $array['tva_label'] = _('Nom TVA');
+        $array['tva_comment'] = _('Commentaire TVA');
+        $array['tva_both_side'] = _('TVA annulée');
+        $array['vat_sided'] = _('TVA Non Payé');
+        $array['vat_code'] = _('Code TVA');
+        $array['vat'] = _('Montant TVA');
+        $array['price'] = _('Total HTVA');
+        $array['quantity'] = _('quantité');
+        $array['price_per_unit'] = _('PU');
+        $array['non_ded_amount'] = _('Montant ND');
+        $array['non_ded_tva'] = _('Montant TVA ND');
+        $array['non_ded_tva_recup'] = _('TVA récup.');
+        $array['htva'] = _('HTVA Opération');
+        $array['tot_vat'] = _('TVA Opération');
+        $array['tot_tva_np'] = _('TVA NP opération');
+        return $array;
+    }
 
 }
 
