@@ -40,6 +40,7 @@ require_once('class_own.php');
 require_once('class_itva_popup.php');
 require_once('class_acc_ledger_fin.php');
 require_once 'class_stock_goods.php';
+require_once 'class_acc_ledger.php';
 
 /* !\brief Handle the ledger of sold,
  *
@@ -61,7 +62,17 @@ class Acc_Ledger_Sold extends Acc_Ledger {
 
     public function verify($p_array) {
         global $g_parameter, $g_user;
+        
+        if (is_array($p_array ) == false || empty($p_array))
+                    throw new Exception ("Array empty");
+        
         extract($p_array);
+        
+        /*
+         * Check needed value
+         */
+        check_parameter($p_array,'p_jrn,e_date,e_client');
+
         /* check for a double reload */
         if (isset($mt) && $this->db->count_sql('select jr_mt from jrn where jr_mt=$1', array($mt)) != 0)
             throw new Exception(_('Double Encodage'), 5);
@@ -304,7 +315,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
                     $oTva->set_parameter("id", $idx_tva);
                     $oTva->load();
                     /* if empty then we need to compute it */
-                    if (trim($tva_item) == '') {
+                    if (trim($tva_item) == '' || ${'e_march'.$i.'_tva_amount'} == 0) {
                         /* retrieve tva */
                         $l = new Acc_Tva($this->db, $idx_tva);
                         $l->load();
@@ -344,7 +355,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
                     $op->oa_group = $group;
                     $op->j_id = $j_id;
                     $op->oa_date = $e_date;
-                    $op->oa_debit = ($amount < 0 ) ? 't' : 'f';
+                    $op->oa_debit = 'f';
                     $op->oa_description = sql_string($e_comm);
                     $op->save_form_plan($_POST, $i, $j_id);
                 }
@@ -572,7 +583,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
             echo $e->getTrace();
 
             $this->db->rollback();
-            exit();
+            throw new Exception ($e);
         }
         $this->db->commit();
 
@@ -742,14 +753,15 @@ class Acc_Ledger_Sold extends Acc_Ledger {
             $r.='<td class="num">';
             $r.=nbm(${"e_quant" . $i});
             $r.='</td>';
+            $both_side=0;
             if ($g_parameter->MY_TVA_USE == 'Y') {
                 $r.='<td class="num">';
                 $r.=$oTva->get_parameter('label');
                 $r.='</td>';
-
+                $both_side=$oTva->get_parameter("both_side");
                 /* warning if tva_computed and given are not the
                   same */
-                if (bcsub($tva_item, $tva_computed) != 0) {
+                if (bcsub($tva_item, $tva_computed) != 0 && ! ($tva_item == 0 && $both_side == 1)) {
                     $r.='<td style="background-color:red" class="num">';
                     $r.=HtmlInput::infobulle(28);
                     $r.='<a href="#" class="error" style="display:inline" title="' . _("Attention Différence entre TVA calculée et donnée") . '">'
@@ -786,20 +798,43 @@ class Acc_Ledger_Sold extends Acc_Ledger {
 
             $r.='</tr>';
         } // end loop item
-
+        //
+        // Add the sum
+        $decalage=($g_parameter->MY_TVA_USE == 'Y')?'<td></td><td></td><td></td><td></td>':'<td></td>';
+         $tot = round(bcadd($tot_amount, $tot_tva), 2);
+        $tot_tva=nbm($tot_tva);
+        $tot=nbm($tot);
+        $str_tot=_('Totaux');
+        $tot_amount=nbm($tot_amount);
+        $r.=<<<EOF
+<tr class="highlight">
+    {$decalage}            
+     <td>
+                {$str_tot}
+     </td>
+    <td class="num">
+        {$tot_tva}
+    </td>
+    <td class="num">
+        {$tot_amount}
+    </td>
+    <td class="num">
+        {$tot}
+    </td>
+EOF;
 
         $r.='</table>';
         $r.='</p>';
         if ($g_parameter->MY_ANALYTIC != 'nu' && ! $p_summary) // use of AA
             $r.='<input type="button" class="button" value="' . _('Vérifiez Imputation Analytique') . '" onClick="verify_ca(\'\');">';
+        $r.=(! $p_summary )?'<div id="total_div_id" >':'<div>';
         $r.='<h2>Totaux</h2>';
-        $r.='<p class="decale">';
-        $tot = round(bcadd($tot_amount, $tot_tva), 2);
+       
         /* use VAT */
         if ($g_parameter->MY_TVA_USE == 'Y') {
             $r.='<table>';
             $r.='<tr><td>Total HTVA</td>';
-            $r.=td(hb(nbm($tot_amount) ),'class="num"');
+            $r.=td(hb($tot_amount ),'class="num"');
             foreach ($tva as $i => $value) {
                 $oTva->set_parameter('id', $i);
                 $oTva->load();
@@ -807,19 +842,13 @@ class Acc_Ledger_Sold extends Acc_Ledger {
                 $r.='<tr><td>  TVA ' . $oTva->get_parameter('label').'</td>';
                 $r.=td(hb(nbm($tva[$i])),'class="num"');
             }
-            $r.='<tr>'.td(_('Total TVA')).td(hb(nbm($tot_tva)),'class="num"');
-            $r.='<tr>'.td(_('Total TVAC')).td(hb(nbm($tot)),'class="num"');
+            $r.='<tr>'.td(_('Total TVA')).td(hb($tot_tva),'class="num"');
+            $r.='<tr>'.td(_('Total TVAC')).td(hb($tot),'class="num"');
             $r.='</table>';
         } else {
             $r.='<br>Total '.hb(nbm($tot));
         }
-       $r.='</p>';
-        if (!$p_summary) {
-            $r.=$this->extra_info();
-        }
-        
-     
-
+        $r.='</div>';
         /*  Add hidden */
         $r.=HtmlInput::hidden('e_client', $e_client);
         $r.=HtmlInput::hidden('nb_item', $nb_item);
@@ -838,18 +867,12 @@ class Acc_Ledger_Sold extends Acc_Ledger {
 
         $e_mp = (isset($e_mp)) ? $e_mp : 0;
         $r.=HtmlInput::hidden('e_mp', $e_mp);
-        // Show the available repository
-        if ($g_parameter->MY_STOCK == 'Y') {
-            $sel = HtmlInput::select_stock($this->db, 'repo', 'W');
-            $sel->readOnly = $p_summary;
-            if ($p_summary == true)
-                $sel->selected = $repo;
-            $r.='<h2>Dépôt</h2>';
-            $r.="<p class=\"decale\"> Dans le dépôt : ";
-            $r.=$sel->input();
-            $r.='</p>';
+        
+        if ( isset($repo) )  {
+            // Show the available repository
+            $r.= $this->select_depot($p_summary,$repo);
         }
-        /* Paid by */
+
         /* if the paymethod is not 0 and if a quick code is given */
         if ($e_mp != 0 && strlen(trim(${'e_mp_qcode_' . $e_mp})) != 0) {
             $r.=HtmlInput::hidden('e_mp_qcode_' . $e_mp, ${'e_mp_qcode_' . $e_mp});
@@ -861,7 +884,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
             $fname = new Fiche($this->db);
             $fname->get_by_qcode(${'e_mp_qcode_' . $e_mp});
             $r.='<h2>' . "Payé par " . ${'e_mp_qcode_' . $e_mp} .
-                    " " . $fname->getName() . '</H2> ' . '<p class="decale">' . _('Déduction acompte ') . h($acompte) . '</p>' .
+                    " " . $fname->getName() . '</h2> ' . '<p class="decale">' . _('Déduction acompte ') . h($acompte) . '</p>' .
                     _('Libellé :') . h($e_comm_paiement) ;
             $r.='<br>';
         }
@@ -889,8 +912,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
      */
 
     public function extra_info() {
-        $r = "";
-        $r.='<h2> Facturation</h2>';
+        $r = '<div id="facturation_div_id" style="height:185px;height:10rem">';
         // check for upload piece
         $file = new IFile();
         $file->table = 0;
@@ -915,10 +937,14 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $r.=_('Numero de bon de commande : ') . $obj->input('bon_comm') . '<br>';
         $r.=_('Autre information : ') . $obj->input('other_info') . '<br>';
         $r.='</p>';
+        $r.='</div>';
         return $r;
     }
 
-    /* !\brief update the payment
+    /**
+     * @brief update the payment
+     * @deprecated
+     * 
      */
 
     function show_unpaid() {
@@ -1031,8 +1057,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
                 $l_form_per = $period->input();
             } catch (Exception $e) {
                 if ($e->getCode() == 1) {
-                    echo _("Aucune période ouverte");
-                    exit();
+                    throw  Exception( _("Aucune période ouverte") );
                 }
             }
             $label = HtmlInput::infobulle(3);
@@ -1052,7 +1077,7 @@ class Acc_Ledger_Sold extends Acc_Ledger {
 
         $wLedger = $this->select_ledger('VEN', 2);
         if ($wLedger == null)
-            exit(_('Pas de journal disponible'));
+            throw  Exception(_('Pas de journal disponible'));
         $wLedger->table = 1;
         $wLedger->javascript = "onChange='update_predef(\"ven\",\"f\",\"".$_REQUEST['ac']."\");$add_js'";
         $wLedger->label = " Journal " . HtmlInput::infobulle(2);
@@ -1142,10 +1167,8 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         for ($i = 0; $i < $max; $i++) {
             // Code id, price & vat code
             //--
-            $march = (isset(${"e_march$i"})) ? ${"e_march$i"} : ""
-            ;
-            $march_price = (isset(${"e_march" . $i . "_price"})) ? ${"e_march" . $i . "_price"} : ""
-            ;
+            $march = (isset(${"e_march$i"})) ? ${"e_march$i"} : "";
+            $march_price = (isset(${"e_march" . $i . "_price"})) ? ${"e_march" . $i . "_price"} : ""  ;
             if ($flag_tva == 'Y') {
                 $march_tva_id = (isset(${"e_march$i" . "_tva_id"})) ? ${"e_march$i" . "_tva_id"} : "";
                 $march_tva_amount = (isset(${"e_march$i" . "_tva_amount"})) ? ${"e_march$i" . "_tva_amount"} : "";
@@ -1301,6 +1324,43 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $ret = $this->db->exec_sql($sql, array($this->id,$p_from, $p_end));
         return $ret;
     }
+    /**
+     * @brief compute an array with the heading cells for the
+     * details, used for the export in CSV
+     * @return array
+     */
+    static function heading_detail_sale()
+    {
+        $array['jr_id'] = _('Numéro opération');
+        $array['jr_date'] = _('Date');
+        $array['jr_date_paid'] = _('Date paiement');
+        $array['jr_ech'] = _('Date échéance');
+        $array['jr_tech_per'] = _('Période');
+        $array['jr_comment'] = _('Libellé');
+        $array['jr_pj_number'] = _('Pièce');
+        $array['jr_internal'] = _('Interne');
+        $array['jr_def_id'] = _('Code journal');
+        $array['j_poste'] = _('Poste');
+        $array['j_text'] = _('Commentaire');
+        $array['j_qcode'] = _('Code Item');
+        $array['item_card'] = _('N° fiche');
+        $array['item_name'] = _('Nom fiche');
+        $array['qs_client'] = _('N° fiche fournisseur');
+        $array['tiers_name'] = _('Nom fournisseur');
+        $array['quick_code'] = _('Code fournisseur');
+        $array['tva_label'] = _('Nom TVA');
+        $array['tva_comment'] = _('Commentaire TVA');
+        $array['tva_both_side'] = _('TVA annulée');
+        $array['vat_sided'] = _('TVA Non Payé');
+        $array['vat_code'] = _('Code TVA');
+        $array['vat'] = _('Montant TVA');
+        $array['price'] = _('Total HTVA');
+        $array['quantity'] = _('quantité');
+        $array['price_per_unit'] = _('PU');
+        $array['htva'] = _('HTVA Opération');
+        $array['tot_vat'] = _('TVA Opération');
+        return $array;
+    }
     /* !\brief test function
      */
 
@@ -1309,6 +1369,6 @@ class Acc_Ledger_Sold extends Acc_Ledger {
         $a = new Acc_Ledger_Sold($cn, 2);
         echo $a->input();
     }
-
-}
+    
+        }
 
