@@ -489,7 +489,7 @@ class Acc_Operation
     function get_quant()
     {
         $ledger_id=$this->get_ledger();
-        if ( $ledger_id=='') throw new Exception('Journal non trouvé');
+        if ( $ledger_id=='') throw new Exception(_('Journal non trouvé'));
         $oledger=new Acc_Ledger($this->db,$ledger_id);
 
         // retrieve info from jrn_info
@@ -561,6 +561,18 @@ class Acc_Operation
                     array($this->jr_id,$p_type,$p_info));
         }
     }
+    
+    function insert_related_action($p_string)
+    {
+        if ($p_string == "") return;
+        $a_action=explode(',',$p_string);
+        for ($i=0;$i<count($a_action);$i++)
+        {
+            $action = new Follow_Up($this->db,$a_action[$i]);
+            $action->operation=$this->jr_id;
+            $action->insert_operation();
+        }
+    }
     static function test_me()
     {
         $_SESSION['g_user']='phpcompta';
