@@ -339,7 +339,7 @@ class Anc_Balance_Double extends Anc_Print
             '</span>';
 
         $r.='</span>';
-        $r.=HtmlInput::submit('Affiche','Affiche');
+        $r.=HtmlInput::submit('Affiche', _('Rechercher'));
         return $r;
     }
     /*!
@@ -463,7 +463,7 @@ class Anc_Balance_Double extends Anc_Print
 
 
         $res=$this->db->exec_sql($sql);
-
+        $this->has_data=Database::num_row($res);
         if ( Database::num_row($res) == 0 )
             return null;
         $a=array();
