@@ -59,7 +59,7 @@ class Anc_Operation
      * @brief signed of the amount
      */
     var $oa_positive;
-    
+    var $in_div; /*< name of the div if any, default empty string*/
     /*!\brief constructor
      *
      */
@@ -69,6 +69,8 @@ class Anc_Operation
         $this->id=$p_id;
         $this->oa_jrnx_id_source=null;
         $this->oa_positive='Y';
+        $this->has_data=0;
+        $this->in_div="";
     }
     /*!\brief add a row  to the table operation_analytique
      * \note if $this->oa_group if 0 then a sequence id will be computed for
@@ -145,9 +147,9 @@ class Anc_Operation
         $cond_poste="";
 
         if ($p_from!="")
-            $cond="and jr_date >= to_date('$p_from','DD.MM.YYYY') ";
+            $cond="and (jr_date >= to_date('$p_from','DD.MM.YYYY')  or oa_date >= to_date('$p_from','DD.MM.YYYY') )";
         if ( $p_to!="" )
-            $cond.="and jr_date <=to_date('$p_to','DD.MM.YYYY')";
+            $cond.="and (jr_date <=to_date('$p_to','DD.MM.YYYY') or  oa_date <=to_date('$p_to','DD.MM.YYYY')) ";
 
         if ($p_from_poste != "" )
             $cond_poste=" and upper(po_name) >= upper('".$p_from_poste."')";
@@ -157,12 +159,13 @@ class Anc_Operation
         if ( isset ( $this->pa_id) && $this->pa_id !='')
             $pa_id_cond= "pa_id=".$this->pa_id." and";
 	$sql="
+        
 	select oa_id,
 	po_name,
 	oa_description,
 	po_description,
 	oa_debit,
-	to_char(jr_date,'DD.MM.YYYY') as oa_date,
+	(case when jr_date is not null then to_char(jr_date,'DD.MM.YYYY') else to_char(oa_date,'DD.MM.YYYY') end )  as oa_date,
 	oa_amount,
 	oa_group,
 	j_id ,
@@ -171,7 +174,8 @@ class Anc_Operation
 	jr_comment,
 	j_poste,
 	jrnx.f_id,
-	( select ad_value from fiche_Detail where f_id=jrnx.f_id and ad_id=23) as qcode
+	( select ad_value from fiche_Detail where f_id=jrnx.f_id and ad_id=23) as qcode,
+        jr_pj_number
 	from operation_analytique as B join poste_analytique using(po_id)
 	left join jrnx using (j_id)
 	left join jrn on  (j_grpt=jr_grpt_id)
@@ -179,7 +183,6 @@ class Anc_Operation
 	order by jr_date,oa_group,oa_debit desc,oa_id";
 
         $RetSql=$this->db->exec_sql($sql);
-
         $array=Database::fetch_all($RetSql);
         return $array;
     }
@@ -252,18 +255,18 @@ class Anc_Operation
                     $ret.='</table>';
 
                 }
-                $ret.='<table id="'.$row['oa_group'].'" style="margin-bottom:2px;border: 1px solid blue; width: 90%;">';
+                $ret.='<table id="'.$row['oa_group'].'" class="result">';
 
-                $ret.="<th>".
-                      $row['oa_date'].
-                      "</th>".
-                      "<th>".
-                      h($row['oa_description']).
-                      "</th>";
+                $ret.="<tr class=\"highlight\">".
+                      td($row['oa_date']).
+                      "<td>".
+                      HtmlInput::detail_op($row['jr_id'],  h($row['oa_description']." ".$row['jr_pj_number'])).
+                      "</td>".
+                        td();
 
-                $ret.="<th>".
+                $ret.="<td>".
                       "Groupe id : ".$row['oa_group'].
-                      "</th>";
+                      "</td>".
 
                 $oldgroup=$group;
 
@@ -315,35 +318,97 @@ class Anc_Operation
      */
     function get_by_jid($p_jid)
     {
-        $sql="select distinct oa_id,
-             po_id,
-             oa_amount,
-             oa_description,
-             oa_debit,
-             j_id,
-             oa_group,
-             oa_date,
-             pa_id,
-             oa_row,
-             oa_positive
-             from operation_analytique join poste_analytique using (po_id)
-             where
-             j_id=$p_jid order by j_id,oa_row,pa_id";
-        $ret=$this->db->exec_sql($sql);
-        $res=Database::fetch_all($ret);
-        if ( $res== false) return null;
+        $array=array();
+        $a_plan=$this->db->get_array('select pa_id from plan_analytique order by pa_id');
+        $res=array();
+        /*
+         * For one oa_row
+         */
+        $a_rowcount=$this->db->get_array("select distinct  oa_row "
+                ." from operation_analytique where j_id=$1 order by oa_row", array($p_jid));
+
+        for ($i=0; $i<count($a_rowcount); $i++)
+        {
+            /*
+             * Get one row as template for filling the missing 
+             */
+            $a_existing=$this->db->get_array('
+                    select distinct oa_id,
+                     po_id,
+                     oa_amount,
+                     oa_description,
+                     oa_debit,
+                     j_id,
+                     oa_group,
+                     oa_date,
+                     pa_id,
+                     oa_row,
+                     oa_positive
+                     from operation_analytique join poste_analytique using (po_id)
+                     where
+                     j_id=$1 and oa_row = $2 
+                     order by j_id,oa_row', 
+                    array($p_jid, $a_rowcount[$i]['oa_row']));
+            
+            // the first row we found will be the template
+            $template=$a_existing[0];
+            /*
+             * For each plan
+             */
+            for ($j=0; $j<count($a_plan); $j++)
+            {
+                /*
+                 * Fetch the row with this pa_id, oa_row, max : 1 row
+                 */
+                $a_fetch=$this->db->get_array('
+                    select distinct oa_id,
+                     po_id,
+                     oa_amount,
+                     oa_description,
+                     oa_debit,
+                     j_id,
+                     oa_group,
+                     oa_date,
+                     pa_id,
+                     oa_row,
+                     oa_positive
+                     from operation_analytique join poste_analytique using (po_id)
+                     where
+                     j_id=$1 and oa_row = $2  and pa_id=$3', array($p_jid,
+                    $a_rowcount[$i]['oa_row'],
+                    $a_plan[$j]['pa_id']
+                        )
+                );
+                if (count($a_fetch)==0)
+                {
+                    $a_fetch=$template;
+                    $a_fetch['pa_id']=$a_plan[$j]['pa_id'];
+                    $a_fetch['po_id']=-1;
+                    $a_fetch['oa_id']='';
+                    $res[]=$a_fetch;
+                }
+                else
+                if (count($a_fetch)==1)
+                {
+                    $res[]=$a_fetch[0];
+                }
+            }
+        }
 
         foreach ($res as $row)
         {
             $a=new Anc_Operation($this->db);
-            foreach ( $row as $attr=>$value )
+            foreach ($row as $attr=> $value)
             {
                 $a->$attr=$row[$attr];
             }
             $array[]=clone $a;
         }
+
+
         return $array;
     }
+
     /*!\brief modify an op from modify_op.php
      *
      */
@@ -425,6 +490,7 @@ class Anc_Operation
      * \param $p_amount amount
      * \param $p_id operation is detailled in a HTML popup, if several
      *  are opened, the tableid MUST be different. So we need to use a new parameter
+     * \param $p_add_button true, show the button, false don't display them
      * \see save_form_plan
     @note
     - op is an array containing the line number
@@ -454,7 +520,7 @@ class Anc_Operation
 
     @endcode
      */
-    function display_form_plan($p_array,$p_null,$p_mode,$p_seq,$p_amount,$p_id='')
+    function display_form_plan($p_array,$p_null,$p_mode,$p_seq,$p_amount,$p_id='',$p_add_button=true)
     {
         if ( $p_array != null)
             extract ($p_array);
@@ -479,7 +545,7 @@ class Anc_Operation
         $count=0;
 
 		$remain=$p_amount;
-		$ctrl_remain="remain".$table_id;
+		$ctrl_remain="remain".$this->in_div.$table_id;
 
         for ( $i=0; $i < $nb_row;$i++)
         {
@@ -522,7 +588,7 @@ class Anc_Operation
 
             }
             $value=new INum();
-			$value->javascript='onchange="format_number(this);anc_refresh_remain(\''.$table_id.'\',\''.$p_seq.'\')"';
+	    $value->javascript='onchange="format_number(this);anc_refresh_remain(\''.$this->in_div.$table_id.'\',\''.$p_seq.'\')"';
             $value->name="val[".$p_seq."][]";
             $value->size=6;
             $value->value=(isset($val[$p_seq][$i]))?$val[$p_seq][$i]:$p_amount;
@@ -534,20 +600,35 @@ class Anc_Operation
         }
 
         $result.="</table>";
-        if ( $p_mode == 1 )
+
+        if ($p_add_button && $p_mode == 1)
         {
             $style_remain=($remain==0)?'style="color:green"':' style="color:red"';
             $result.=" Reste à imputer =  ".
-                            '<span class="remain" '.$style_remain.' id="'.$ctrl_remain.'">'.
+                     '<span class="remain" '.$style_remain.' id="'.$ctrl_remain.'">'.
                             $remain.'</span>';
-
             // add a button to add a row
             $button=new IButton();
             $button->javascript="add_row('".$p_id."$table_id',$p_seq);";
             $button->name="js".$p_id.$p_seq;
-            $button->label="Nouvelle ligne";
+            $button->label=_("Nouvelle ligne");
 
             $result.="<br>".$button->input();
+            /**
+             * Add a button for distribution key
+             * 
+             */
+            $ledger=HtmlInput::default_value_post("p_jrn", 0);
+            if ($ledger==0) {
+                $ledger=$this->db->get_value('select j_jrn_def from jrnx where j_id=$1',array($this->j_id));
+            }
+            $gDossier=Dossier::id();
+            $button_key=new IButton();
+            $button_key->javascript="anc_key_choice(".$gDossier.",'".$p_id."$table_id',$p_amount,'".$ledger."');";
+            $button_key->name="js".$p_id.$p_seq;
+            $button_key->label=_("Clef");
+            $result .= $button_key->input();
+
         }
 
         return $result;
@@ -707,13 +788,20 @@ class Anc_Operation
         extract($p_array);
         for ($i = 0; $i < count($op); $i++)
         {
-            /* clean jrnx */
+            /* clean operation_analytique */
             $this->db->exec_sql('delete from operation_analytique where j_id=$1', array($op[$i]));
 
             /* get missing data for adding */
-            $a_missing = $this->db->get_array("select to_char(jr_date,'DD.MM.YYYY') as mdate,j_montant,j_debit,jr_comment from jrnx join jrn on (j_grpt=jr_grpt_id) where j_id=$1", array($op[$i]));
+            $a_missing = $this->db->get_array("select to_char(jr_date,'DD.MM.YYYY') 
+                    as mdate,j_montant,j_debit,jr_comment ,j_poste
+                    from jrnx join jrn on (j_grpt=jr_grpt_id) where j_id=$1", array($op[$i]));
             $missing = $a_missing[0];
-            $this->oa_debit = $missing['j_debit'];
+            $poste=substr(trim($missing['j_poste']),0,1);
+            if ( $poste == 6 || $poste == 7)  {
+                $this->oa_debit = ($poste == 6) ?'t':'f';
+            }else {
+                $this->oa_debit=$missing['j_debit'];
+            }
             $this->oa_description = $missing['jr_comment'];
             $this->j_id = $op[$i];
             $group = $this->db->get_next_seq("s_oa_group"); /* for analytic */
@@ -733,7 +821,7 @@ class Anc_Operation
                     /* get missing data for adding */
                     $a_missing_vat = $this->db->get_array("select to_char(jr_date,'DD.MM.YYYY') as mdate,j_montant,j_debit,jr_comment from jrnx join jrn on (j_grpt=jr_grpt_id) where j_id=$1", array($a_nd[$e]['j_id']));
                     $missing_vat = $a_missing_vat[0];
-                    $this->oa_debit = $missing_vat['j_debit'];
+                    $this->oa_debit = 't';
                     $this->oa_description = $missing_vat['jr_comment'];
                     $this->j_id = $op[$i];
                     $group = $this->db->get_next_seq("s_oa_group"); /* for analytic */
@@ -776,9 +864,21 @@ class Anc_Operation
         $result['hplan']=$hplan;
         /* Add the amount */
         $idx_pa=0;
+        $jrn_def=$this->db->get_value('select jrn_def_type from jrnx join jrn_def on (j_jrn_def=jrn_def_id) where j_id=$1',array($this->j_id));
         for ($i=0;$i < count($p_array);$i++)
         {
-            $val[$p_line][$p_array[$i]->oa_row]=($p_array[$i]->oa_positive=='Y')?$p_array[$i]->oa_amount:($p_array[$i]->oa_amount*(-1));
+            
+            /*
+             * For the bank, negatif are always on the debit and positif on the credit
+             */
+            if ( $jrn_def != 'FIN')
+            {
+                $val[$p_line][$p_array[$i]->oa_row]=($p_array[$i]->oa_positive=='Y')?$p_array[$i]->oa_amount:($p_array[$i]->oa_amount*(-1));
+            }
+            else
+            {
+                $val[$p_line][$p_array[$i]->oa_row]=$p_array[$i]->oa_amount;
+            }
         }
         $result['val']=$val;
         return $result;
