@@ -47,6 +47,7 @@ class Document
     {
         $this->db=$p_cn;
         $this->d_id=$p_d_id;
+        $this->counter=0;
     }
     /*!\brief insert a minimal document and set the d_id
      */
@@ -146,8 +147,7 @@ class Document
             $res = $zip->open($filename, ZipArchive::CREATE);
             if($res !== TRUE)
 	      {
-		echo __FILE__.":".__LINE__."cannot recreate zip";
-		exit;
+		throw new Exception ( __FILE__.":".__LINE__."cannot recreate zip");
 	      }
 	    $zip->add_recurse_folder($dirname.DIRECTORY_SEPARATOR);
 	    $zip->close();
@@ -197,8 +197,8 @@ class Document
         {
             if ( mkdir($temp_dir) == false )
             {
-                echo "Ne peut pas créer le répertoire ".$temp_dir;
-                exit();
+                $msg=_("Ne peut pas créer le répertoire ".$temp_dir); 
+                throw new Exception($msg);
             }
         }
         // Compute output_name
@@ -208,12 +208,14 @@ class Document
         if (  $h === false )
         {
             echo __FILE__.":".__LINE__."cannot open $p_dir $p_file ";
-            exit();
+            $msg=_("Ne peut pas ouvrir $p_dir $p_file"); 
+            throw new Exception($msg);
         }
         if ( $output_file == false)
         {
-            echo "ne peut pas ouvrir le fichier de sortie";
-            exit();
+            $msg=_("Ne peut pas ouvrir $p_dir $p_file"); 
+            echo $msg;
+            throw new Exception($msg);
         }
         // compute the regex
         if ( $p_type=='OOo')
@@ -506,7 +508,6 @@ class Document
      *  - [VEN_ART_PRICE]
      *  - [VEN_ART_QUANT]
      *  - [VEN_ART_TVA_CODE]
-     *  - [VEN_ART_TVA_AMOUNT]
      *  - [VEN_ART_STOCK_CODE]
      *  - [VEN_HTVA]
      *  - [VEN_TVAC]
@@ -554,7 +555,7 @@ class Document
         $p_tag=strtoupper($p_tag);
         $p_tag=str_replace('=','',$p_tag);
         $r="Tag inconnu";
-        static $counter=0;
+
         switch ($p_tag)
         {
 		case 'DATE':
@@ -816,7 +817,6 @@ class Document
              *  - [VEN_ART_PRICE]
              *  - [VEN_ART_QUANT]
              *  - [VEN_ART_TVA_CODE]
-             *  - [VEN_ART_TVA_AMOUNT]
              *  - [VEN_ART_STOCK_CODE]
              *  - [VEN_HTVA]
              *  - [VEN_TVAC]
@@ -837,17 +837,17 @@ class Document
             $r=${$id};
             break;
         case 'MARCH_NEXT':
-            $counter++;
+            $this->counter++;
             $r='';
             break;
 
         case 'VEN_ART_NAME':
             extract ($p_array);
-            $id='e_march'.$counter;
+            $id='e_march'.$this->counter;
             // check if the march exists
             if ( ! isset (${$id})) return "";
             // check that something is sold
-            if ( ${'e_march'.$counter.'_price'} != 0 && ${'e_quant'.$counter} != 0 )
+            if ( ${'e_march'.$this->counter.'_price'} != 0 && ${'e_quant'.$this->counter} != 0 )
             {
                 $f=new Fiche($this->db);
                 $f->get_by_qcode(${$id},false);
@@ -857,19 +857,19 @@ class Document
             break;
        case 'VEN_ART_LABEL':
             extract ($p_array);
-            $id='e_march'.$counter."_label";
+            $id='e_march'.$this->counter."_label";
             // check if the march exists
 
             if (! isset (${$id}) || (isset (${$id}) && strlen(trim(${$id})) == 0))
                 {
-                    $id = 'e_march' . $counter;
+                    $id = 'e_march' . $this->counter;
                     // check if the march exists
                     if (!isset(${$id}))
                         $r= "";
                     else 
                     {
                     // check that something is sold
-                        if (${'e_march' . $counter . '_price'} != 0 && ${'e_quant' . $counter} != 0)
+                        if (${'e_march' . $this->counter . '_price'} != 0 && ${'e_quant' . $this->counter} != 0)
                         {
                             $f = new Fiche($this->db);
                             $f->get_by_qcode(${$id}, false);
@@ -879,12 +879,29 @@ class Document
                     }
                 }
                 else
-                    $r=${'e_march'.$counter.'_label'};
+                    $r=${'e_march'.$this->counter.'_label'};
+            break;
+        case 'VEN_ART_STOCK_CODE':
+            extract ($p_array);
+                    $id = 'e_march' . $this->counter;
+                    // check if the march exists
+                    if (!isset(${$id}))
+                        $r= "";
+                    else 
+                    {
+                    // check that something is sold
+                        if (${'e_march' . $this->counter . '_price'} != 0 && ${'e_quant' . $this->counter} != 0)
+                        {
+                            $f = new Fiche($this->db);
+                            $f->get_by_qcode(${$id}, false);
+                            $r = $f->strAttribut(ATTR_DEF_STOCK);
+                            $r=($r == NOTFOUND)?'':$r;
+                        } 
+                    }
             break;
-
         case 'VEN_ART_PRICE':
             extract ($p_array);
-            $id='e_march'.$counter.'_price' ;
+            $id='e_march'.$this->counter.'_price' ;
             if ( !isset (${$id}) ) return "";
 			if (${$id} == 0 ) return "";
             $r=${$id};
@@ -893,10 +910,10 @@ class Document
         case 'TVA_RATE':
         case 'VEN_ART_TVA_RATE':
             extract ($p_array);
-            $id='e_march'.$counter.'_tva_id';
+            $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
             if ( ${$id} == -1 || ${$id}=='' ) return "";
-            $march_id='e_march'.$counter.'_price' ;
+            $march_id='e_march'.$this->counter.'_price' ;
             if ( ! isset (${$march_id})) return '';
             $tva=new Acc_Tva($this->db);
             $tva->set_parameter("id",${$id});
@@ -907,11 +924,11 @@ class Document
         case 'TVA_CODE':
         case 'VEN_ART_TVA_CODE':
             extract ($p_array);
-            $id='e_march'.$counter.'_tva_id';
+            $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
             if ( ${$id} == -1 ) return "";
-            $qt='e_quant'.$counter;
-            $price='e_march'.$counter.'_price' ;
+            $qt='e_quant'.$this->counter;
+            $price='e_march'.$this->counter.'_price' ;
             if ( ${$price} == 0 || ${$qt} == 0
                     || strlen(trim( $price )) ==0
                     || strlen(trim($qt)) ==0)
@@ -922,9 +939,9 @@ class Document
 
         case 'TVA_LABEL':
             extract ($p_array);
-            $id='e_march'.$counter.'_tva_id';
+            $id='e_march'.$this->counter.'_tva_id';
             if ( !isset (${$id}) ) return "";
-            $march_id='e_march'.$counter.'_price' ;
+            $march_id='e_march'.$this->counter.'_price' ;
             if ( ! isset (${$march_id})) return '';
             if ( ${$march_id} == 0) return '';
             $tva=new Acc_Tva($this->db,${$id});
@@ -935,27 +952,29 @@ class Document
 
             /* total VAT for one sold */
         case 'TVA_AMOUNT':
+        case 'VEN_TVA':
             extract ($p_array);
-            $qt='e_quant'.$counter;
-            $price='e_march'.$counter.'_price' ;
-            $tva='e_march'.$counter.'_tva_id';
+            $qt='e_quant'.$this->counter;
+            $price='e_march'.$this->counter.'_price' ;
+            $tva='e_march'.$this->counter.'_tva_id';
             /* if we do not use vat this var. is not set */
             if ( !isset(${$tva}) ) return '';
-            if ( !isset (${'e_march'.$counter}) ) return "";
+            if ( !isset (${'e_march'.$this->counter}) ) return "";
             // check that something is sold
             if ( ${$price} == 0 || ${$qt} == 0
                     || strlen(trim( $price )) ==0
                     || strlen(trim($qt)) ==0)
                 return "";
-            $r=${'e_march'.$counter.'_tva_amount'};
+            $r=${'e_march'.$this->counter.'_tva_amount'};
             break;
             /* TVA automatically computed */
         case 'VEN_ART_TVA':
+        
             extract ($p_array);
-            $qt='e_quant'.$counter;
-            $price='e_march'.$counter.'_price' ;
-            $tva='e_march'.$counter.'_tva_id';
-            if ( !isset (${'e_march'.$counter}) ) return "";
+            $qt='e_quant'.$this->counter;
+            $price='e_march'.$this->counter.'_price' ;
+            $tva='e_march'.$this->counter.'_tva_id';
+            if ( !isset (${'e_march'.$this->counter}) ) return "";
             // check that something is sold
             if ( ${$price} == 0 || ${$qt} == 0
                     || strlen(trim( $price )) ==0
@@ -969,10 +988,10 @@ class Document
 
         case 'VEN_ART_TVAC':
             extract ($p_array);
-            $qt='e_quant'.$counter;
-            $price='e_march'.$counter.'_price' ;
-            $tva='e_march'.$counter.'_tva_id';
-            if ( !isset (${'e_march'.$counter}) ) return "";
+            $qt='e_quant'.$this->counter;
+            $price='e_march'.$this->counter.'_price' ;
+            $tva='e_march'.$this->counter.'_tva_id';
+            if ( !isset (${'e_march'.$this->counter}) ) return "";
             // check that something is sold
             if ( ${$price} == 0 || ${$qt} == 0
                     || strlen(trim( $price )) ==0
@@ -993,27 +1012,27 @@ class Document
 
         case 'VEN_ART_QUANT':
             extract ($p_array);
-            $id='e_quant'.$counter;
+            $id='e_quant'.$this->counter;
             if ( !isset (${$id}) ) return "";
             // check that something is sold
-            if ( ${'e_march'.$counter.'_price'} == 0
-                    || ${'e_quant'.$counter} == 0
-                    || strlen(trim( ${'e_march'.$counter.'_price'} )) ==0
-                    || strlen(trim(${'e_quant'.$counter})) ==0 )
+            if ( ${'e_march'.$this->counter.'_price'} == 0
+                    || ${'e_quant'.$this->counter} == 0
+                    || strlen(trim( ${'e_march'.$this->counter.'_price'} )) ==0
+                    || strlen(trim(${'e_quant'.$this->counter})) ==0 )
                 return "";
             $r=${$id};
             break;
 
         case 'VEN_HTVA':
             extract ($p_array);
-            $id='e_march'.$counter.'_price' ;
-            $quant='e_quant'.$counter;
+            $id='e_march'.$this->counter.'_price' ;
+            $quant='e_quant'.$this->counter;
             if ( !isset (${$id}) ) return "";
 
             // check that something is sold
-            if ( ${'e_march'.$counter.'_price'} == 0 || ${'e_quant'.$counter} == 0
-                    || strlen(trim( ${'e_march'.$counter.'_price'} )) ==0
-                    || strlen(trim(${'e_quant'.$counter})) ==0)
+            if ( ${'e_march'.$this->counter.'_price'} == 0 || ${'e_quant'.$this->counter} == 0
+                    || strlen(trim( ${'e_march'.$this->counter.'_price'} )) ==0
+                    || strlen(trim(${'e_quant'.$this->counter})) ==0)
                 return "";
 			bcscale(4);
             $r=bcmul(${$id},${$quant});
@@ -1022,12 +1041,12 @@ class Document
 
         case 'VEN_TVAC':
             extract ($p_array);
-            $id='e_march'.$counter.'_tva_amount' ;
-            $price='e_march'.$counter.'_price' ;
-            $quant='e_quant'.$counter;
-            if ( ! isset(${'e_march'.$counter.'_price'})|| !isset(${'e_quant'.$counter}))     return "";
+            $id='e_march'.$this->counter.'_tva_amount' ;
+            $price='e_march'.$this->counter.'_price' ;
+            $quant='e_quant'.$this->counter;
+            if ( ! isset(${'e_march'.$this->counter.'_price'})|| !isset(${'e_quant'.$this->counter}))     return "";
             // check that something is sold
-            if ( ${'e_march'.$counter.'_price'} == 0 || ${'e_quant'.$counter} == 0 ) return "";
+            if ( ${'e_march'.$this->counter.'_price'} == 0 || ${'e_quant'.$this->counter} == 0 ) return "";
 			bcscale(4);
             // if TVA not exist
             if ( ! isset(${$id}))
@@ -1128,29 +1147,29 @@ class Document
                 return $p_array['acompte'];
 			return "0";
             break;
-		case 'STOCK_NAME':
-			if ( ! isset ($p_array['repo'])) return "";
-			$ret=$this->db->get_value('select r_name from public.stock_repository where r_id=$1',array($p_array['repo']));
-			return $ret;
-		case 'STOCK_ADRESS':
-			if ( ! isset ($p_array['repo'])) return "";
-			$ret=$this->db->get_value('select r_adress from public.stock_repository where r_id=$1',array($p_array['repo']));
-			return $ret;
-		case 'STOCK_COUNTRY':
-			if ( ! isset ($p_array['repo'])) return "";
-			$ret=$this->db->get_value('select r_country from public.stock_repository where r_id=$1',array($p_array['repo']));
-			return $ret;
-		case 'STOCK_CITY':
-			if ( ! isset ($p_array['repo'])) return "";
-			$ret=$this->db->get_value('select r_city from public.stock_repository where r_id=$1',array($p_array['repo']));
-			return $ret;
-		case 'STOCK_PHONE':
-			if ( ! isset ($p_array['repo'])) return "";
-			$ret=$this->db->get_value('select r_phone from public.stock_repository where r_id=$1',array($p_array['repo']));
-			return $ret;
-                case 'TITLE':
-                    $title=HtmlInput::default_value_request("ag_title", "");
-                    return $title;
+        case 'STOCK_NAME':
+                if ( ! isset ($p_array['repo'])) return "";
+                $ret=$this->db->get_value('select r_name from public.stock_repository where r_id=$1',array($p_array['repo']));
+                return $ret;
+        case 'STOCK_ADRESS':
+                if ( ! isset ($p_array['repo'])) return "";
+                $ret=$this->db->get_value('select r_adress from public.stock_repository where r_id=$1',array($p_array['repo']));
+                return $ret;
+        case 'STOCK_COUNTRY':
+                if ( ! isset ($p_array['repo'])) return "";
+                $ret=$this->db->get_value('select r_country from public.stock_repository where r_id=$1',array($p_array['repo']));
+                return $ret;
+        case 'STOCK_CITY':
+                if ( ! isset ($p_array['repo'])) return "";
+                $ret=$this->db->get_value('select r_city from public.stock_repository where r_id=$1',array($p_array['repo']));
+                return $ret;
+        case 'STOCK_PHONE':
+                if ( ! isset ($p_array['repo'])) return "";
+                $ret=$this->db->get_value('select r_phone from public.stock_repository where r_id=$1',array($p_array['repo']));
+                return $ret;
+        case 'TITLE':
+            $title=HtmlInput::default_value_request("ag_title", "");
+            return $title;
 
 		}
         /*
@@ -1159,9 +1178,9 @@ class Document
         if (preg_match('/^ATTR/', $p_tag) == 1)
         {
             // Retrieve f_id
-            if ( isset ($p_array['e_march'.$counter]))
+            if ( isset ($p_array['e_march'.$this->counter]))
             {
-                $id = $p_array['e_march' . $counter];
+                $id = $p_array['e_march' . $this->counter];
                 $r=$this->replace_special_tag($id,$p_tag);
             }
         }
