@@ -352,6 +352,7 @@ class HtmlInput
         echo '</form>';
         echo '</div>';
         echo '</div>';
+  
         $ret=ob_get_contents();
         ob_end_clean();
         return $ret;
@@ -426,8 +427,8 @@ class HtmlInput
     static function anchor_close($div)
     {
 	$r='';
-	$r.='<div style="float:right;margin-right:2px;margin-top:5px;padding:0px;">';
-	$r.= '<A id="close_div" class="input_text" HREF="javascript:void(0)" onclick="removeDiv(\''.$div.'\');">'._('Fermer').'</A>';
+	$r.='<div style="position:absolute;right:2px;margin:2px;padding:0px;">';
+	$r.= '<A id="close_div" class="input_text" onclick="removeDiv(\''.$div.'\');">'._('Fermer').'</A>';
 	$r.='</div>';
 	return $r;
     }
@@ -445,6 +446,23 @@ class HtmlInput
 		$r.='<input type="button" id="'.$id.'" class="'.$p_class.'" onclick="'.$javascript.'" value="'.h($action).'">';
 		return $r;
 
+    }
+    /**
+     * button Html image
+     *@param $javascript javascript to execute
+     * @param $id id of the button
+     * @param  $class class of the button
+     * @param $p_image image
+     */
+    static function button_image($javascript,$id="xx",$p_class='class="button"',$p_image="")
+    {
+        if ($id=="xx"){
+            $id=HtmlInput::generate_id("xx");
+        }
+        $r="";
+        $r.='<image id="'.$id.'" '.$p_class.' onclick="'.$javascript.'"  src="'.$p_image.'" />';
+        return $r;
+
     }
     /**
      * Return a html string with an anchor to hide a div, put it in the right corner
@@ -456,7 +474,7 @@ class HtmlInput
     static function anchor_hide($action,$javascript)
     {
 	$r='';
-	$r.='<div style="float:right;margin:2px;">';
+	$r.='<div style="position:absolute;margin:2px;right:2px">';
 	$r.= '<span id="close_div" class="input_text"  onclick="'.$javascript.'">'.$action.'</span>';
 	$r.='</div>';
 	return $r;
@@ -683,10 +701,18 @@ class HtmlInput
 		}
 		return $_REQUEST[$ind];
 	}
-	static function title_box($name,$div,$mod="close")
+        /**
+         * Title for boxes
+         * @param type $name Title
+         * @param type $div element id
+         * @param type $mod hide or close
+         * @param type $p_js if $mod is hide then you can add a javascript
+         * @return type
+         */
+	static function title_box($name,$div,$mod="close",$p_js="")
 	{
 		if ($mod=='close')		$r=HtmlInput::anchor_close($div);
-		if ($mod=='hide')		$r=HtmlInput::anchor_hide(_('Fermer'),"$('$div').hide()");
+		if ($mod=='hide')		$r=HtmlInput::anchor_hide(_('Fermer'),"$('$div').hide();$p_js");
                 if ( $mod == 'none')    $r="";
 		$r.=h2($name,' class="title" ');
 		return $r;
@@ -699,8 +725,9 @@ class HtmlInput
          * @param string $p_text text of the anchor
          * @param string $p_url  url
          * @param string $p_js javascript
+         * @param string $p_style is the visuable effect (class, style...)
          */
-      static function anchor($p_text,$p_url="",$p_js="")
+      static function anchor($p_text,$p_url="",$p_js="",$p_style=' class="line" ')
       {
           if ($p_js != "")
           {
@@ -708,8 +735,8 @@ class HtmlInput
           }
 
 
-          $str=sprintf('<a class="line" href="%s" %s>%s</a>',
-                  $p_url,$p_js,$p_text);
+          $str=sprintf('<a %s href="%s" %s>%s</a>',
+                  $p_style,$p_url,$p_js,$p_text);
           return $str;
       }
       /**
@@ -761,6 +788,7 @@ class HtmlInput
 			<input type=\"button\" class=\"smallbutton\" onclick=\"$('lk_".$p_table_id."').value='';filter_table($('lk_".$p_table_id."'), '$p_table_id','$p_col',$start_row );\" value=\"X\">
 			</span>
 			";
+                $r.=' <span class="notice" id="info_'.$p_table_id.'"></span>';
 		return $r;
 	}
 
@@ -822,5 +850,45 @@ class HtmlInput
             echo $hid_jrn;
             echo '</span>';
         }
-
+        /**
+         * Returns HTML code for displaying a icon with a link to a receipt document from
+         * the ledger 
+         * @global $cn database connx
+         * @param $p_jr_id jrn.jr_id
+         * @return nothing or HTML Code for a link to the document
+         */
+        static function show_receipt_document($p_jr_id)
+        {
+            global $cn;
+            
+            $array=$cn->get_array('select jr_def_id,jr_pj_name,jr_grpt_id from jrn where jr_id=$1',array($p_jr_id));
+            if (count($array)==0) return "";
+            if ($array[0]['jr_pj_name'] == "") return "";
+            $str_dossier=Dossier::get();
+            $image='<IMG style="width:24px;height:24px;border:0px" SRC="image/documents.png" title="' . $array[0]['jr_pj_name'] . '" >';
+            $r=sprintf('<A class="detail" HREF="show_pj.php?jrn=%s&jr_grpt_id=%s&%s">%s</A>', $array[0]['jr_def_id'], $array[0]['jr_grpt_id'], $str_dossier, $image);
+            return $r;
+            
+        }
+        /**
+         * 
+         * @param type $p_operation_jr_id action_gestion_operation.ago_id
+         */
+        static function  button_action_remove_operation($p_operation) 
+        {
+            $rmOperation=sprintf("javascript:if ( confirm('"._('Voulez-vous effacer cette relation ')."')==true ) {remove_operation('%s','%s');}",
+							dossier::id(),
+							$p_operation);
+            $js= '<a class="tinybutton" id="acop'.$p_operation.'" href="'.$rmOperation.'">'."&#x2D5D;".'</a>';
+            return $js;
+        }
+        static function button_action_add_concerned_card($p_agid)
+        {
+            $dossier=Dossier::id();
+            $javascript= <<<EOF
+                    obj={dossier:$dossier,ag_id:$p_agid};action_add_concerned_card(obj);
+EOF;
+            $js=HtmlInput::button_action(_('Ajout autres'), $javascript);
+            return $js;
+        }
 }
