@@ -36,7 +36,7 @@ $cn=new Database(dossier::id());
 $str_dossier=dossier::get();
 $ac="ac=".$_REQUEST['ac'];
 global $g_parameter;
-
+$p_msg="";
 //----------------------------------------------------------------------
 // Encode a new invoice
 // empty form for encoding
@@ -64,31 +64,55 @@ global $g_parameter;
         catch (Exception $e)
         {
             alert($e->getMessage());
+            $p_msg=$e->getMessage();
             $correct=1;
         }
         // if correct is not set it means it is correct
         if ( ! isset($correct))
         {
             echo '<div class="content">';
-            echo h1('Confirmation','');
-            echo_warning("Attention, cette opération n'est pas encore sauvée : vous devez encore confirmer");
 
+            echo '<div id="confirm_div_id" style="width: 47%; float: left;">';
+            echo h1(_("Confirmation"));
+            echo '</div>';
 
+            echo '<div id="warning_ven_id" class="notice" style="width: 50%; margin-left: 0px; float: right;">';
+            echo h2(_("Attention, cette opération n'est pas encore sauvée : vous devez encore confirmer"),' class="notice"');
+            echo '</div>';
+            
+            echo '<div id="confirm_div_id" style="width: 100%; float: left;">';
             echo '<form class="print" enctype="multipart/form-data" method="post">';
             echo dossier::hidden();
             echo $Ledger->confirm($_POST );
-			echo HtmlInput::hidden('ac',$_REQUEST['ac']);
-	    echo '<div style="clear:both">';
-            
+            echo HtmlInput::hidden('ac',$_REQUEST['ac']);
+            ?>
+<div id="tab_id" >
+<ul class="tabs">
+    <li class="tabs_selected"><a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('repo_div_id').hide();$('facturation_div_id').show();"><?php echo _('Facture')?></a></li>
+    <li class="tabs"> <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('modele_div_id').hide();$('facturation_div_id').hide();$('repo_div_id').show();"> <?php echo _('Dépôt')?> </a></li>
+    <li class="tabs"> <a href="javascript:void(0)" onclick="unselect_other_tab(this.parentNode.parentNode);this.parentNode.className='tabs_selected';$('facturation_div_id').hide();$('repo_div_id').hide();$('modele_div_id').show()"> <?php echo _('Modèle')?> </a></li>
+</ul>
+<?php
+            echo $Ledger->select_depot(false, -1);
+            echo $Ledger->extra_info();
+	    echo '<div id="modele_div_id" style="display:none;height:185px;height:10rem">';
             echo Pre_operation::save_propose();
 	    echo '</div>';
+            
 	    echo HtmlInput::hidden('ac',$_REQUEST['ac']);
             echo HtmlInput::submit("record",_("Enregistrement"),'onClick="return verify_ca(\'\');"');
             echo HtmlInput::submit('correct',_("Corriger"));
             echo '</form>';
-
             echo '</div>';
-            exit();
+            echo '</div>'; /* tab_id */
+?>
+<script>
+    $('repo_div_id').hide();
+    $('modele_div_id').hide();
+</script>
+<?php
+            echo '</div>';
+            return;
         }
     }
     //------------------------------
@@ -118,7 +142,11 @@ global $g_parameter;
 
         if ( ! isset($correct))
         {
-            echo '<div class="content">';
+            if ( is_msie() == 0 ) 
+                echo '<div style="position:absolute"  class="content">';
+             else
+                echo '<div class="content">';
+
             $Ledger=new Acc_Ledger_Sold($cn,$_POST['p_jrn']);
             $internal=$Ledger->insert($_POST);
 
@@ -131,7 +159,7 @@ global $g_parameter;
             }
 
             /* Show button  */
-            echo '<h1 > Enregistrement </h1>';
+            echo '<h1 style="float:right;margin-right:20%"> Enregistrement </h1>';
 
             echo $Ledger->confirm($_POST,true);
             /* Show link for Invoice */
@@ -146,9 +174,10 @@ global $g_parameter;
             $obj=new Acc_Ledger_Info($cn);
             $obj->save_extra($Ledger->jr_id,$_POST);
 
+            echo $Ledger->button_new_operation();
 
             echo '</div>';
-            exit();
+            return;
         }
     }
     //  ------------------------------
@@ -160,7 +189,11 @@ global $g_parameter;
 //
 // pre defined operation
 //
-echo '<div class="content">';
+if ( is_msie() == 0 ) 
+    echo '<div style="position:absolute"  class="content">';
+else
+    echo '<div class="content">';
+
     if ( !isset($_REQUEST ['p_jrn']) )
     {
         $def_ledger=$Ledger->get_first('ven',2);
@@ -187,6 +220,7 @@ echo '<div class="content">';
     echo '</div>';
 
    echo '<div class="content">';
+   echo '<p class="notice">'.$p_msg.'</p>';
  echo "<FORM class=\"print\" NAME=\"form_detail\" METHOD=\"POST\" >";
     /* request for a predefined operation */
     if (  isset($_REQUEST['pre_def']) && ! isset($_POST['correct']) )
@@ -234,6 +268,8 @@ echo '<div class="content">';
         echo '</script>';
     }
     echo '<div class="content">';
+
+
     echo HtmlInput::button('act',_('Actualiser'),'onClick="compute_all_ledger();"');
     echo HtmlInput::submit("view_invoice",_("Enregistrer"));
     echo HtmlInput::reset(_('Effacer '));
@@ -250,5 +286,5 @@ echo '<div class="content">';
 		echo create_script(" get_last_date()");
 	}
 echo create_script(" update_name()");	
-exit();
+return;
 ?>
